# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.

"""
Quantity module, see official documentation at
https://dev.opencascade.org/doc/occt-7.9.0/refman/html/package_quantity.html
"""

from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _Quantity
else:
    import _Quantity

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _Quantity.delete_SwigPyIterator

    def value(self):
        return _Quantity.SwigPyIterator_value(self)

    def incr(self, n=1):
        return _Quantity.SwigPyIterator_incr(self, n)

    def decr(self, n=1):
        return _Quantity.SwigPyIterator_decr(self, n)

    def distance(self, x):
        return _Quantity.SwigPyIterator_distance(self, x)

    def equal(self, x):
        return _Quantity.SwigPyIterator_equal(self, x)

    def copy(self):
        return _Quantity.SwigPyIterator_copy(self)

    def next(self):
        return _Quantity.SwigPyIterator_next(self)

    def __next__(self):
        return _Quantity.SwigPyIterator___next__(self)

    def previous(self):
        return _Quantity.SwigPyIterator_previous(self)

    def advance(self, n):
        return _Quantity.SwigPyIterator_advance(self, n)

    def __eq__(self, x):
        return _Quantity.SwigPyIterator___eq__(self, x)

    def __ne__(self, x):
        return _Quantity.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n):
        return _Quantity.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n):
        return _Quantity.SwigPyIterator___isub__(self, n)

    def __add__(self, n):
        return _Quantity.SwigPyIterator___add__(self, n)

    def __sub__(self, *args):
        return _Quantity.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _Quantity:
_Quantity.SwigPyIterator_swigregister(SwigPyIterator)

def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error, method_name, class_name):
    return _Quantity.process_exception(error, method_name, class_name)

import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

class ios_base(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr
    erase_event = _Quantity.ios_base_erase_event
    imbue_event = _Quantity.ios_base_imbue_event
    copyfmt_event = _Quantity.ios_base_copyfmt_event

    def register_callback(self, __fn, __index):
        return _Quantity.ios_base_register_callback(self, __fn, __index)

    def flags(self, *args):
        return _Quantity.ios_base_flags(self, *args)

    def setf(self, *args):
        return _Quantity.ios_base_setf(self, *args)

    def unsetf(self, __mask):
        return _Quantity.ios_base_unsetf(self, __mask)

    def precision(self, *args):
        return _Quantity.ios_base_precision(self, *args)

    def width(self, *args):
        return _Quantity.ios_base_width(self, *args)

    @staticmethod
    def sync_with_stdio(__sync=True):
        return _Quantity.ios_base_sync_with_stdio(__sync)

    def imbue(self, __loc):
        return _Quantity.ios_base_imbue(self, __loc)

    def getloc(self):
        return _Quantity.ios_base_getloc(self)

    @staticmethod
    def xalloc():
        return _Quantity.ios_base_xalloc()

    def iword(self, __ix):
        return _Quantity.ios_base_iword(self, __ix)

    def pword(self, __ix):
        return _Quantity.ios_base_pword(self, __ix)
    __swig_destroy__ = _Quantity.delete_ios_base

# Register ios_base in _Quantity:
_Quantity.ios_base_swigregister(ios_base)
cvar = _Quantity.cvar
ios_base.boolalpha = _Quantity.cvar.ios_base_boolalpha
ios_base.dec = _Quantity.cvar.ios_base_dec
ios_base.fixed = _Quantity.cvar.ios_base_fixed
ios_base.hex = _Quantity.cvar.ios_base_hex
ios_base.internal = _Quantity.cvar.ios_base_internal
ios_base.left = _Quantity.cvar.ios_base_left
ios_base.oct = _Quantity.cvar.ios_base_oct
ios_base.right = _Quantity.cvar.ios_base_right
ios_base.scientific = _Quantity.cvar.ios_base_scientific
ios_base.showbase = _Quantity.cvar.ios_base_showbase
ios_base.showpoint = _Quantity.cvar.ios_base_showpoint
ios_base.showpos = _Quantity.cvar.ios_base_showpos
ios_base.skipws = _Quantity.cvar.ios_base_skipws
ios_base.unitbuf = _Quantity.cvar.ios_base_unitbuf
ios_base.uppercase = _Quantity.cvar.ios_base_uppercase
ios_base.adjustfield = _Quantity.cvar.ios_base_adjustfield
ios_base.basefield = _Quantity.cvar.ios_base_basefield
ios_base.floatfield = _Quantity.cvar.ios_base_floatfield
ios_base.badbit = _Quantity.cvar.ios_base_badbit
ios_base.eofbit = _Quantity.cvar.ios_base_eofbit
ios_base.failbit = _Quantity.cvar.ios_base_failbit
ios_base.goodbit = _Quantity.cvar.ios_base_goodbit
ios_base.app = _Quantity.cvar.ios_base_app
ios_base.ate = _Quantity.cvar.ios_base_ate
ios_base.binary = _Quantity.cvar.ios_base_binary
ios_base.ios_base_in = _Quantity.cvar.ios_base_ios_base_in
ios_base.out = _Quantity.cvar.ios_base_out
ios_base.trunc = _Quantity.cvar.ios_base_trunc
ios_base.beg = _Quantity.cvar.ios_base_beg
ios_base.cur = _Quantity.cvar.ios_base_cur
ios_base.end = _Quantity.cvar.ios_base_end

class ios(ios_base):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def rdstate(self):
        return _Quantity.ios_rdstate(self)

    def clear(self, *args):
        return _Quantity.ios_clear(self, *args)

    def setstate(self, __state):
        return _Quantity.ios_setstate(self, __state)

    def good(self):
        return _Quantity.ios_good(self)

    def eof(self):
        return _Quantity.ios_eof(self)

    def fail(self):
        return _Quantity.ios_fail(self)

    def bad(self):
        return _Quantity.ios_bad(self)

    def exceptions(self, *args):
        return _Quantity.ios_exceptions(self, *args)

    def __init__(self, __sb):
        _Quantity.ios_swiginit(self, _Quantity.new_ios(__sb))
    __swig_destroy__ = _Quantity.delete_ios

    def tie(self, *args):
        return _Quantity.ios_tie(self, *args)

    def rdbuf(self, *args):
        return _Quantity.ios_rdbuf(self, *args)

    def copyfmt(self, __rhs):
        return _Quantity.ios_copyfmt(self, __rhs)

    def fill(self, *args):
        return _Quantity.ios_fill(self, *args)

    def imbue(self, __loc):
        return _Quantity.ios_imbue(self, __loc)

    def narrow(self, __c, __dfault):
        return _Quantity.ios_narrow(self, __c, __dfault)

    def widen(self, __c):
        return _Quantity.ios_widen(self, __c)

# Register ios in _Quantity:
_Quantity.ios_swigregister(ios)
class ostream(ios):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, __sb):
        _Quantity.ostream_swiginit(self, _Quantity.new_ostream(__sb))
    __swig_destroy__ = _Quantity.delete_ostream

    def __lshift__(self, *args):
        return _Quantity.ostream___lshift__(self, *args)

    def put(self, __c):
        return _Quantity.ostream_put(self, __c)

    def write(self, __s, __n):
        return _Quantity.ostream_write(self, __s, __n)

    def flush(self):
        return _Quantity.ostream_flush(self)

    def tellp(self):
        return _Quantity.ostream_tellp(self)

    def seekp(self, *args):
        return _Quantity.ostream_seekp(self, *args)

# Register ostream in _Quantity:
_Quantity.ostream_swigregister(ostream)
class istream(ios):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, __sb):
        _Quantity.istream_swiginit(self, _Quantity.new_istream(__sb))
    __swig_destroy__ = _Quantity.delete_istream

    def __rshift__(self, *args):
        return _Quantity.istream___rshift__(self, *args)

    def gcount(self):
        return _Quantity.istream_gcount(self)

    def get(self, *args):
        return _Quantity.istream_get(self, *args)

    def getline(self, *args):
        return _Quantity.istream_getline(self, *args)

    def ignore(self, *args):
        return _Quantity.istream_ignore(self, *args)

    def peek(self):
        return _Quantity.istream_peek(self)

    def read(self, __s, __n):
        return _Quantity.istream_read(self, __s, __n)

    def readsome(self, __s, __n):
        return _Quantity.istream_readsome(self, __s, __n)

    def putback(self, __c):
        return _Quantity.istream_putback(self, __c)

    def unget(self):
        return _Quantity.istream_unget(self)

    def sync(self):
        return _Quantity.istream_sync(self)

    def tellg(self):
        return _Quantity.istream_tellg(self)

    def seekg(self, *args):
        return _Quantity.istream_seekg(self, *args)

# Register istream in _Quantity:
_Quantity.istream_swigregister(istream)
class iostream(istream, ostream):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, __sb):
        _Quantity.iostream_swiginit(self, _Quantity.new_iostream(__sb))
    __swig_destroy__ = _Quantity.delete_iostream

# Register iostream in _Quantity:
_Quantity.iostream_swigregister(iostream)
cin = cvar.cin
cout = cvar.cout
cerr = cvar.cerr
clog = cvar.clog

endl_cb_ptr = _Quantity.endl_cb_ptr
endl = _Quantity.endl
ends_cb_ptr = _Quantity.ends_cb_ptr
ends = _Quantity.ends
flush_cb_ptr = _Quantity.flush_cb_ptr
flush = _Quantity.flush
import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.TCollection

from enum import IntEnum
from OCC.Core.Exception import *

Quantity_NOC_BLACK = _Quantity.Quantity_NOC_BLACK
Quantity_NOC_MATRABLUE = _Quantity.Quantity_NOC_MATRABLUE
Quantity_NOC_MATRAGRAY = _Quantity.Quantity_NOC_MATRAGRAY
Quantity_NOC_ALICEBLUE = _Quantity.Quantity_NOC_ALICEBLUE
Quantity_NOC_ANTIQUEWHITE = _Quantity.Quantity_NOC_ANTIQUEWHITE
Quantity_NOC_ANTIQUEWHITE1 = _Quantity.Quantity_NOC_ANTIQUEWHITE1
Quantity_NOC_ANTIQUEWHITE2 = _Quantity.Quantity_NOC_ANTIQUEWHITE2
Quantity_NOC_ANTIQUEWHITE3 = _Quantity.Quantity_NOC_ANTIQUEWHITE3
Quantity_NOC_ANTIQUEWHITE4 = _Quantity.Quantity_NOC_ANTIQUEWHITE4
Quantity_NOC_AQUAMARINE1 = _Quantity.Quantity_NOC_AQUAMARINE1
Quantity_NOC_AQUAMARINE2 = _Quantity.Quantity_NOC_AQUAMARINE2
Quantity_NOC_AQUAMARINE4 = _Quantity.Quantity_NOC_AQUAMARINE4
Quantity_NOC_AZURE = _Quantity.Quantity_NOC_AZURE
Quantity_NOC_AZURE2 = _Quantity.Quantity_NOC_AZURE2
Quantity_NOC_AZURE3 = _Quantity.Quantity_NOC_AZURE3
Quantity_NOC_AZURE4 = _Quantity.Quantity_NOC_AZURE4
Quantity_NOC_BEIGE = _Quantity.Quantity_NOC_BEIGE
Quantity_NOC_BISQUE = _Quantity.Quantity_NOC_BISQUE
Quantity_NOC_BISQUE2 = _Quantity.Quantity_NOC_BISQUE2
Quantity_NOC_BISQUE3 = _Quantity.Quantity_NOC_BISQUE3
Quantity_NOC_BISQUE4 = _Quantity.Quantity_NOC_BISQUE4
Quantity_NOC_BLANCHEDALMOND = _Quantity.Quantity_NOC_BLANCHEDALMOND
Quantity_NOC_BLUE = _Quantity.Quantity_NOC_BLUE
Quantity_NOC_BLUE1 = _Quantity.Quantity_NOC_BLUE1
Quantity_NOC_BLUE2 = _Quantity.Quantity_NOC_BLUE2
Quantity_NOC_BLUE3 = _Quantity.Quantity_NOC_BLUE3
Quantity_NOC_BLUE4 = _Quantity.Quantity_NOC_BLUE4
Quantity_NOC_BLUEVIOLET = _Quantity.Quantity_NOC_BLUEVIOLET
Quantity_NOC_BROWN = _Quantity.Quantity_NOC_BROWN
Quantity_NOC_BROWN1 = _Quantity.Quantity_NOC_BROWN1
Quantity_NOC_BROWN2 = _Quantity.Quantity_NOC_BROWN2
Quantity_NOC_BROWN3 = _Quantity.Quantity_NOC_BROWN3
Quantity_NOC_BROWN4 = _Quantity.Quantity_NOC_BROWN4
Quantity_NOC_BURLYWOOD = _Quantity.Quantity_NOC_BURLYWOOD
Quantity_NOC_BURLYWOOD1 = _Quantity.Quantity_NOC_BURLYWOOD1
Quantity_NOC_BURLYWOOD2 = _Quantity.Quantity_NOC_BURLYWOOD2
Quantity_NOC_BURLYWOOD3 = _Quantity.Quantity_NOC_BURLYWOOD3
Quantity_NOC_BURLYWOOD4 = _Quantity.Quantity_NOC_BURLYWOOD4
Quantity_NOC_CADETBLUE = _Quantity.Quantity_NOC_CADETBLUE
Quantity_NOC_CADETBLUE1 = _Quantity.Quantity_NOC_CADETBLUE1
Quantity_NOC_CADETBLUE2 = _Quantity.Quantity_NOC_CADETBLUE2
Quantity_NOC_CADETBLUE3 = _Quantity.Quantity_NOC_CADETBLUE3
Quantity_NOC_CADETBLUE4 = _Quantity.Quantity_NOC_CADETBLUE4
Quantity_NOC_CHARTREUSE = _Quantity.Quantity_NOC_CHARTREUSE
Quantity_NOC_CHARTREUSE1 = _Quantity.Quantity_NOC_CHARTREUSE1
Quantity_NOC_CHARTREUSE2 = _Quantity.Quantity_NOC_CHARTREUSE2
Quantity_NOC_CHARTREUSE3 = _Quantity.Quantity_NOC_CHARTREUSE3
Quantity_NOC_CHARTREUSE4 = _Quantity.Quantity_NOC_CHARTREUSE4
Quantity_NOC_CHOCOLATE = _Quantity.Quantity_NOC_CHOCOLATE
Quantity_NOC_CHOCOLATE1 = _Quantity.Quantity_NOC_CHOCOLATE1
Quantity_NOC_CHOCOLATE2 = _Quantity.Quantity_NOC_CHOCOLATE2
Quantity_NOC_CHOCOLATE3 = _Quantity.Quantity_NOC_CHOCOLATE3
Quantity_NOC_CHOCOLATE4 = _Quantity.Quantity_NOC_CHOCOLATE4
Quantity_NOC_CORAL = _Quantity.Quantity_NOC_CORAL
Quantity_NOC_CORAL1 = _Quantity.Quantity_NOC_CORAL1
Quantity_NOC_CORAL2 = _Quantity.Quantity_NOC_CORAL2
Quantity_NOC_CORAL3 = _Quantity.Quantity_NOC_CORAL3
Quantity_NOC_CORAL4 = _Quantity.Quantity_NOC_CORAL4
Quantity_NOC_CORNFLOWERBLUE = _Quantity.Quantity_NOC_CORNFLOWERBLUE
Quantity_NOC_CORNSILK1 = _Quantity.Quantity_NOC_CORNSILK1
Quantity_NOC_CORNSILK2 = _Quantity.Quantity_NOC_CORNSILK2
Quantity_NOC_CORNSILK3 = _Quantity.Quantity_NOC_CORNSILK3
Quantity_NOC_CORNSILK4 = _Quantity.Quantity_NOC_CORNSILK4
Quantity_NOC_CYAN = _Quantity.Quantity_NOC_CYAN
Quantity_NOC_CYAN1 = _Quantity.Quantity_NOC_CYAN1
Quantity_NOC_CYAN2 = _Quantity.Quantity_NOC_CYAN2
Quantity_NOC_CYAN3 = _Quantity.Quantity_NOC_CYAN3
Quantity_NOC_CYAN4 = _Quantity.Quantity_NOC_CYAN4
Quantity_NOC_DARKGOLDENROD = _Quantity.Quantity_NOC_DARKGOLDENROD
Quantity_NOC_DARKGOLDENROD1 = _Quantity.Quantity_NOC_DARKGOLDENROD1
Quantity_NOC_DARKGOLDENROD2 = _Quantity.Quantity_NOC_DARKGOLDENROD2
Quantity_NOC_DARKGOLDENROD3 = _Quantity.Quantity_NOC_DARKGOLDENROD3
Quantity_NOC_DARKGOLDENROD4 = _Quantity.Quantity_NOC_DARKGOLDENROD4
Quantity_NOC_DARKGREEN = _Quantity.Quantity_NOC_DARKGREEN
Quantity_NOC_DARKKHAKI = _Quantity.Quantity_NOC_DARKKHAKI
Quantity_NOC_DARKOLIVEGREEN = _Quantity.Quantity_NOC_DARKOLIVEGREEN
Quantity_NOC_DARKOLIVEGREEN1 = _Quantity.Quantity_NOC_DARKOLIVEGREEN1
Quantity_NOC_DARKOLIVEGREEN2 = _Quantity.Quantity_NOC_DARKOLIVEGREEN2
Quantity_NOC_DARKOLIVEGREEN3 = _Quantity.Quantity_NOC_DARKOLIVEGREEN3
Quantity_NOC_DARKOLIVEGREEN4 = _Quantity.Quantity_NOC_DARKOLIVEGREEN4
Quantity_NOC_DARKORANGE = _Quantity.Quantity_NOC_DARKORANGE
Quantity_NOC_DARKORANGE1 = _Quantity.Quantity_NOC_DARKORANGE1
Quantity_NOC_DARKORANGE2 = _Quantity.Quantity_NOC_DARKORANGE2
Quantity_NOC_DARKORANGE3 = _Quantity.Quantity_NOC_DARKORANGE3
Quantity_NOC_DARKORANGE4 = _Quantity.Quantity_NOC_DARKORANGE4
Quantity_NOC_DARKORCHID = _Quantity.Quantity_NOC_DARKORCHID
Quantity_NOC_DARKORCHID1 = _Quantity.Quantity_NOC_DARKORCHID1
Quantity_NOC_DARKORCHID2 = _Quantity.Quantity_NOC_DARKORCHID2
Quantity_NOC_DARKORCHID3 = _Quantity.Quantity_NOC_DARKORCHID3
Quantity_NOC_DARKORCHID4 = _Quantity.Quantity_NOC_DARKORCHID4
Quantity_NOC_DARKSALMON = _Quantity.Quantity_NOC_DARKSALMON
Quantity_NOC_DARKSEAGREEN = _Quantity.Quantity_NOC_DARKSEAGREEN
Quantity_NOC_DARKSEAGREEN1 = _Quantity.Quantity_NOC_DARKSEAGREEN1
Quantity_NOC_DARKSEAGREEN2 = _Quantity.Quantity_NOC_DARKSEAGREEN2
Quantity_NOC_DARKSEAGREEN3 = _Quantity.Quantity_NOC_DARKSEAGREEN3
Quantity_NOC_DARKSEAGREEN4 = _Quantity.Quantity_NOC_DARKSEAGREEN4
Quantity_NOC_DARKSLATEBLUE = _Quantity.Quantity_NOC_DARKSLATEBLUE
Quantity_NOC_DARKSLATEGRAY1 = _Quantity.Quantity_NOC_DARKSLATEGRAY1
Quantity_NOC_DARKSLATEGRAY2 = _Quantity.Quantity_NOC_DARKSLATEGRAY2
Quantity_NOC_DARKSLATEGRAY3 = _Quantity.Quantity_NOC_DARKSLATEGRAY3
Quantity_NOC_DARKSLATEGRAY4 = _Quantity.Quantity_NOC_DARKSLATEGRAY4
Quantity_NOC_DARKSLATEGRAY = _Quantity.Quantity_NOC_DARKSLATEGRAY
Quantity_NOC_DARKTURQUOISE = _Quantity.Quantity_NOC_DARKTURQUOISE
Quantity_NOC_DARKVIOLET = _Quantity.Quantity_NOC_DARKVIOLET
Quantity_NOC_DEEPPINK = _Quantity.Quantity_NOC_DEEPPINK
Quantity_NOC_DEEPPINK2 = _Quantity.Quantity_NOC_DEEPPINK2
Quantity_NOC_DEEPPINK3 = _Quantity.Quantity_NOC_DEEPPINK3
Quantity_NOC_DEEPPINK4 = _Quantity.Quantity_NOC_DEEPPINK4
Quantity_NOC_DEEPSKYBLUE1 = _Quantity.Quantity_NOC_DEEPSKYBLUE1
Quantity_NOC_DEEPSKYBLUE2 = _Quantity.Quantity_NOC_DEEPSKYBLUE2
Quantity_NOC_DEEPSKYBLUE3 = _Quantity.Quantity_NOC_DEEPSKYBLUE3
Quantity_NOC_DEEPSKYBLUE4 = _Quantity.Quantity_NOC_DEEPSKYBLUE4
Quantity_NOC_DODGERBLUE1 = _Quantity.Quantity_NOC_DODGERBLUE1
Quantity_NOC_DODGERBLUE2 = _Quantity.Quantity_NOC_DODGERBLUE2
Quantity_NOC_DODGERBLUE3 = _Quantity.Quantity_NOC_DODGERBLUE3
Quantity_NOC_DODGERBLUE4 = _Quantity.Quantity_NOC_DODGERBLUE4
Quantity_NOC_FIREBRICK = _Quantity.Quantity_NOC_FIREBRICK
Quantity_NOC_FIREBRICK1 = _Quantity.Quantity_NOC_FIREBRICK1
Quantity_NOC_FIREBRICK2 = _Quantity.Quantity_NOC_FIREBRICK2
Quantity_NOC_FIREBRICK3 = _Quantity.Quantity_NOC_FIREBRICK3
Quantity_NOC_FIREBRICK4 = _Quantity.Quantity_NOC_FIREBRICK4
Quantity_NOC_FLORALWHITE = _Quantity.Quantity_NOC_FLORALWHITE
Quantity_NOC_FORESTGREEN = _Quantity.Quantity_NOC_FORESTGREEN
Quantity_NOC_GAINSBORO = _Quantity.Quantity_NOC_GAINSBORO
Quantity_NOC_GHOSTWHITE = _Quantity.Quantity_NOC_GHOSTWHITE
Quantity_NOC_GOLD = _Quantity.Quantity_NOC_GOLD
Quantity_NOC_GOLD1 = _Quantity.Quantity_NOC_GOLD1
Quantity_NOC_GOLD2 = _Quantity.Quantity_NOC_GOLD2
Quantity_NOC_GOLD3 = _Quantity.Quantity_NOC_GOLD3
Quantity_NOC_GOLD4 = _Quantity.Quantity_NOC_GOLD4
Quantity_NOC_GOLDENROD = _Quantity.Quantity_NOC_GOLDENROD
Quantity_NOC_GOLDENROD1 = _Quantity.Quantity_NOC_GOLDENROD1
Quantity_NOC_GOLDENROD2 = _Quantity.Quantity_NOC_GOLDENROD2
Quantity_NOC_GOLDENROD3 = _Quantity.Quantity_NOC_GOLDENROD3
Quantity_NOC_GOLDENROD4 = _Quantity.Quantity_NOC_GOLDENROD4
Quantity_NOC_GRAY = _Quantity.Quantity_NOC_GRAY
Quantity_NOC_GRAY0 = _Quantity.Quantity_NOC_GRAY0
Quantity_NOC_GRAY1 = _Quantity.Quantity_NOC_GRAY1
Quantity_NOC_GRAY2 = _Quantity.Quantity_NOC_GRAY2
Quantity_NOC_GRAY3 = _Quantity.Quantity_NOC_GRAY3
Quantity_NOC_GRAY4 = _Quantity.Quantity_NOC_GRAY4
Quantity_NOC_GRAY5 = _Quantity.Quantity_NOC_GRAY5
Quantity_NOC_GRAY6 = _Quantity.Quantity_NOC_GRAY6
Quantity_NOC_GRAY7 = _Quantity.Quantity_NOC_GRAY7
Quantity_NOC_GRAY8 = _Quantity.Quantity_NOC_GRAY8
Quantity_NOC_GRAY9 = _Quantity.Quantity_NOC_GRAY9
Quantity_NOC_GRAY10 = _Quantity.Quantity_NOC_GRAY10
Quantity_NOC_GRAY11 = _Quantity.Quantity_NOC_GRAY11
Quantity_NOC_GRAY12 = _Quantity.Quantity_NOC_GRAY12
Quantity_NOC_GRAY13 = _Quantity.Quantity_NOC_GRAY13
Quantity_NOC_GRAY14 = _Quantity.Quantity_NOC_GRAY14
Quantity_NOC_GRAY15 = _Quantity.Quantity_NOC_GRAY15
Quantity_NOC_GRAY16 = _Quantity.Quantity_NOC_GRAY16
Quantity_NOC_GRAY17 = _Quantity.Quantity_NOC_GRAY17
Quantity_NOC_GRAY18 = _Quantity.Quantity_NOC_GRAY18
Quantity_NOC_GRAY19 = _Quantity.Quantity_NOC_GRAY19
Quantity_NOC_GRAY20 = _Quantity.Quantity_NOC_GRAY20
Quantity_NOC_GRAY21 = _Quantity.Quantity_NOC_GRAY21
Quantity_NOC_GRAY22 = _Quantity.Quantity_NOC_GRAY22
Quantity_NOC_GRAY23 = _Quantity.Quantity_NOC_GRAY23
Quantity_NOC_GRAY24 = _Quantity.Quantity_NOC_GRAY24
Quantity_NOC_GRAY25 = _Quantity.Quantity_NOC_GRAY25
Quantity_NOC_GRAY26 = _Quantity.Quantity_NOC_GRAY26
Quantity_NOC_GRAY27 = _Quantity.Quantity_NOC_GRAY27
Quantity_NOC_GRAY28 = _Quantity.Quantity_NOC_GRAY28
Quantity_NOC_GRAY29 = _Quantity.Quantity_NOC_GRAY29
Quantity_NOC_GRAY30 = _Quantity.Quantity_NOC_GRAY30
Quantity_NOC_GRAY31 = _Quantity.Quantity_NOC_GRAY31
Quantity_NOC_GRAY32 = _Quantity.Quantity_NOC_GRAY32
Quantity_NOC_GRAY33 = _Quantity.Quantity_NOC_GRAY33
Quantity_NOC_GRAY34 = _Quantity.Quantity_NOC_GRAY34
Quantity_NOC_GRAY35 = _Quantity.Quantity_NOC_GRAY35
Quantity_NOC_GRAY36 = _Quantity.Quantity_NOC_GRAY36
Quantity_NOC_GRAY37 = _Quantity.Quantity_NOC_GRAY37
Quantity_NOC_GRAY38 = _Quantity.Quantity_NOC_GRAY38
Quantity_NOC_GRAY39 = _Quantity.Quantity_NOC_GRAY39
Quantity_NOC_GRAY40 = _Quantity.Quantity_NOC_GRAY40
Quantity_NOC_GRAY41 = _Quantity.Quantity_NOC_GRAY41
Quantity_NOC_GRAY42 = _Quantity.Quantity_NOC_GRAY42
Quantity_NOC_GRAY43 = _Quantity.Quantity_NOC_GRAY43
Quantity_NOC_GRAY44 = _Quantity.Quantity_NOC_GRAY44
Quantity_NOC_GRAY45 = _Quantity.Quantity_NOC_GRAY45
Quantity_NOC_GRAY46 = _Quantity.Quantity_NOC_GRAY46
Quantity_NOC_GRAY47 = _Quantity.Quantity_NOC_GRAY47
Quantity_NOC_GRAY48 = _Quantity.Quantity_NOC_GRAY48
Quantity_NOC_GRAY49 = _Quantity.Quantity_NOC_GRAY49
Quantity_NOC_GRAY50 = _Quantity.Quantity_NOC_GRAY50
Quantity_NOC_GRAY51 = _Quantity.Quantity_NOC_GRAY51
Quantity_NOC_GRAY52 = _Quantity.Quantity_NOC_GRAY52
Quantity_NOC_GRAY53 = _Quantity.Quantity_NOC_GRAY53
Quantity_NOC_GRAY54 = _Quantity.Quantity_NOC_GRAY54
Quantity_NOC_GRAY55 = _Quantity.Quantity_NOC_GRAY55
Quantity_NOC_GRAY56 = _Quantity.Quantity_NOC_GRAY56
Quantity_NOC_GRAY57 = _Quantity.Quantity_NOC_GRAY57
Quantity_NOC_GRAY58 = _Quantity.Quantity_NOC_GRAY58
Quantity_NOC_GRAY59 = _Quantity.Quantity_NOC_GRAY59
Quantity_NOC_GRAY60 = _Quantity.Quantity_NOC_GRAY60
Quantity_NOC_GRAY61 = _Quantity.Quantity_NOC_GRAY61
Quantity_NOC_GRAY62 = _Quantity.Quantity_NOC_GRAY62
Quantity_NOC_GRAY63 = _Quantity.Quantity_NOC_GRAY63
Quantity_NOC_GRAY64 = _Quantity.Quantity_NOC_GRAY64
Quantity_NOC_GRAY65 = _Quantity.Quantity_NOC_GRAY65
Quantity_NOC_GRAY66 = _Quantity.Quantity_NOC_GRAY66
Quantity_NOC_GRAY67 = _Quantity.Quantity_NOC_GRAY67
Quantity_NOC_GRAY68 = _Quantity.Quantity_NOC_GRAY68
Quantity_NOC_GRAY69 = _Quantity.Quantity_NOC_GRAY69
Quantity_NOC_GRAY70 = _Quantity.Quantity_NOC_GRAY70
Quantity_NOC_GRAY71 = _Quantity.Quantity_NOC_GRAY71
Quantity_NOC_GRAY72 = _Quantity.Quantity_NOC_GRAY72
Quantity_NOC_GRAY73 = _Quantity.Quantity_NOC_GRAY73
Quantity_NOC_GRAY74 = _Quantity.Quantity_NOC_GRAY74
Quantity_NOC_GRAY75 = _Quantity.Quantity_NOC_GRAY75
Quantity_NOC_GRAY76 = _Quantity.Quantity_NOC_GRAY76
Quantity_NOC_GRAY77 = _Quantity.Quantity_NOC_GRAY77
Quantity_NOC_GRAY78 = _Quantity.Quantity_NOC_GRAY78
Quantity_NOC_GRAY79 = _Quantity.Quantity_NOC_GRAY79
Quantity_NOC_GRAY80 = _Quantity.Quantity_NOC_GRAY80
Quantity_NOC_GRAY81 = _Quantity.Quantity_NOC_GRAY81
Quantity_NOC_GRAY82 = _Quantity.Quantity_NOC_GRAY82
Quantity_NOC_GRAY83 = _Quantity.Quantity_NOC_GRAY83
Quantity_NOC_GRAY85 = _Quantity.Quantity_NOC_GRAY85
Quantity_NOC_GRAY86 = _Quantity.Quantity_NOC_GRAY86
Quantity_NOC_GRAY87 = _Quantity.Quantity_NOC_GRAY87
Quantity_NOC_GRAY88 = _Quantity.Quantity_NOC_GRAY88
Quantity_NOC_GRAY89 = _Quantity.Quantity_NOC_GRAY89
Quantity_NOC_GRAY90 = _Quantity.Quantity_NOC_GRAY90
Quantity_NOC_GRAY91 = _Quantity.Quantity_NOC_GRAY91
Quantity_NOC_GRAY92 = _Quantity.Quantity_NOC_GRAY92
Quantity_NOC_GRAY93 = _Quantity.Quantity_NOC_GRAY93
Quantity_NOC_GRAY94 = _Quantity.Quantity_NOC_GRAY94
Quantity_NOC_GRAY95 = _Quantity.Quantity_NOC_GRAY95
Quantity_NOC_GRAY97 = _Quantity.Quantity_NOC_GRAY97
Quantity_NOC_GRAY98 = _Quantity.Quantity_NOC_GRAY98
Quantity_NOC_GRAY99 = _Quantity.Quantity_NOC_GRAY99
Quantity_NOC_GREEN = _Quantity.Quantity_NOC_GREEN
Quantity_NOC_GREEN1 = _Quantity.Quantity_NOC_GREEN1
Quantity_NOC_GREEN2 = _Quantity.Quantity_NOC_GREEN2
Quantity_NOC_GREEN3 = _Quantity.Quantity_NOC_GREEN3
Quantity_NOC_GREEN4 = _Quantity.Quantity_NOC_GREEN4
Quantity_NOC_GREENYELLOW = _Quantity.Quantity_NOC_GREENYELLOW
Quantity_NOC_HONEYDEW = _Quantity.Quantity_NOC_HONEYDEW
Quantity_NOC_HONEYDEW2 = _Quantity.Quantity_NOC_HONEYDEW2
Quantity_NOC_HONEYDEW3 = _Quantity.Quantity_NOC_HONEYDEW3
Quantity_NOC_HONEYDEW4 = _Quantity.Quantity_NOC_HONEYDEW4
Quantity_NOC_HOTPINK = _Quantity.Quantity_NOC_HOTPINK
Quantity_NOC_HOTPINK1 = _Quantity.Quantity_NOC_HOTPINK1
Quantity_NOC_HOTPINK2 = _Quantity.Quantity_NOC_HOTPINK2
Quantity_NOC_HOTPINK3 = _Quantity.Quantity_NOC_HOTPINK3
Quantity_NOC_HOTPINK4 = _Quantity.Quantity_NOC_HOTPINK4
Quantity_NOC_INDIANRED = _Quantity.Quantity_NOC_INDIANRED
Quantity_NOC_INDIANRED1 = _Quantity.Quantity_NOC_INDIANRED1
Quantity_NOC_INDIANRED2 = _Quantity.Quantity_NOC_INDIANRED2
Quantity_NOC_INDIANRED3 = _Quantity.Quantity_NOC_INDIANRED3
Quantity_NOC_INDIANRED4 = _Quantity.Quantity_NOC_INDIANRED4
Quantity_NOC_IVORY = _Quantity.Quantity_NOC_IVORY
Quantity_NOC_IVORY2 = _Quantity.Quantity_NOC_IVORY2
Quantity_NOC_IVORY3 = _Quantity.Quantity_NOC_IVORY3
Quantity_NOC_IVORY4 = _Quantity.Quantity_NOC_IVORY4
Quantity_NOC_KHAKI = _Quantity.Quantity_NOC_KHAKI
Quantity_NOC_KHAKI1 = _Quantity.Quantity_NOC_KHAKI1
Quantity_NOC_KHAKI2 = _Quantity.Quantity_NOC_KHAKI2
Quantity_NOC_KHAKI3 = _Quantity.Quantity_NOC_KHAKI3
Quantity_NOC_KHAKI4 = _Quantity.Quantity_NOC_KHAKI4
Quantity_NOC_LAVENDER = _Quantity.Quantity_NOC_LAVENDER
Quantity_NOC_LAVENDERBLUSH1 = _Quantity.Quantity_NOC_LAVENDERBLUSH1
Quantity_NOC_LAVENDERBLUSH2 = _Quantity.Quantity_NOC_LAVENDERBLUSH2
Quantity_NOC_LAVENDERBLUSH3 = _Quantity.Quantity_NOC_LAVENDERBLUSH3
Quantity_NOC_LAVENDERBLUSH4 = _Quantity.Quantity_NOC_LAVENDERBLUSH4
Quantity_NOC_LAWNGREEN = _Quantity.Quantity_NOC_LAWNGREEN
Quantity_NOC_LEMONCHIFFON1 = _Quantity.Quantity_NOC_LEMONCHIFFON1
Quantity_NOC_LEMONCHIFFON2 = _Quantity.Quantity_NOC_LEMONCHIFFON2
Quantity_NOC_LEMONCHIFFON3 = _Quantity.Quantity_NOC_LEMONCHIFFON3
Quantity_NOC_LEMONCHIFFON4 = _Quantity.Quantity_NOC_LEMONCHIFFON4
Quantity_NOC_LIGHTBLUE = _Quantity.Quantity_NOC_LIGHTBLUE
Quantity_NOC_LIGHTBLUE1 = _Quantity.Quantity_NOC_LIGHTBLUE1
Quantity_NOC_LIGHTBLUE2 = _Quantity.Quantity_NOC_LIGHTBLUE2
Quantity_NOC_LIGHTBLUE3 = _Quantity.Quantity_NOC_LIGHTBLUE3
Quantity_NOC_LIGHTBLUE4 = _Quantity.Quantity_NOC_LIGHTBLUE4
Quantity_NOC_LIGHTCORAL = _Quantity.Quantity_NOC_LIGHTCORAL
Quantity_NOC_LIGHTCYAN = _Quantity.Quantity_NOC_LIGHTCYAN
Quantity_NOC_LIGHTCYAN1 = _Quantity.Quantity_NOC_LIGHTCYAN1
Quantity_NOC_LIGHTCYAN2 = _Quantity.Quantity_NOC_LIGHTCYAN2
Quantity_NOC_LIGHTCYAN3 = _Quantity.Quantity_NOC_LIGHTCYAN3
Quantity_NOC_LIGHTCYAN4 = _Quantity.Quantity_NOC_LIGHTCYAN4
Quantity_NOC_LIGHTGOLDENROD = _Quantity.Quantity_NOC_LIGHTGOLDENROD
Quantity_NOC_LIGHTGOLDENROD1 = _Quantity.Quantity_NOC_LIGHTGOLDENROD1
Quantity_NOC_LIGHTGOLDENROD2 = _Quantity.Quantity_NOC_LIGHTGOLDENROD2
Quantity_NOC_LIGHTGOLDENROD3 = _Quantity.Quantity_NOC_LIGHTGOLDENROD3
Quantity_NOC_LIGHTGOLDENROD4 = _Quantity.Quantity_NOC_LIGHTGOLDENROD4
Quantity_NOC_LIGHTGOLDENRODYELLOW = _Quantity.Quantity_NOC_LIGHTGOLDENRODYELLOW
Quantity_NOC_LIGHTGRAY = _Quantity.Quantity_NOC_LIGHTGRAY
Quantity_NOC_LIGHTPINK = _Quantity.Quantity_NOC_LIGHTPINK
Quantity_NOC_LIGHTPINK1 = _Quantity.Quantity_NOC_LIGHTPINK1
Quantity_NOC_LIGHTPINK2 = _Quantity.Quantity_NOC_LIGHTPINK2
Quantity_NOC_LIGHTPINK3 = _Quantity.Quantity_NOC_LIGHTPINK3
Quantity_NOC_LIGHTPINK4 = _Quantity.Quantity_NOC_LIGHTPINK4
Quantity_NOC_LIGHTSALMON1 = _Quantity.Quantity_NOC_LIGHTSALMON1
Quantity_NOC_LIGHTSALMON2 = _Quantity.Quantity_NOC_LIGHTSALMON2
Quantity_NOC_LIGHTSALMON3 = _Quantity.Quantity_NOC_LIGHTSALMON3
Quantity_NOC_LIGHTSALMON4 = _Quantity.Quantity_NOC_LIGHTSALMON4
Quantity_NOC_LIGHTSEAGREEN = _Quantity.Quantity_NOC_LIGHTSEAGREEN
Quantity_NOC_LIGHTSKYBLUE = _Quantity.Quantity_NOC_LIGHTSKYBLUE
Quantity_NOC_LIGHTSKYBLUE1 = _Quantity.Quantity_NOC_LIGHTSKYBLUE1
Quantity_NOC_LIGHTSKYBLUE2 = _Quantity.Quantity_NOC_LIGHTSKYBLUE2
Quantity_NOC_LIGHTSKYBLUE3 = _Quantity.Quantity_NOC_LIGHTSKYBLUE3
Quantity_NOC_LIGHTSKYBLUE4 = _Quantity.Quantity_NOC_LIGHTSKYBLUE4
Quantity_NOC_LIGHTSLATEBLUE = _Quantity.Quantity_NOC_LIGHTSLATEBLUE
Quantity_NOC_LIGHTSLATEGRAY = _Quantity.Quantity_NOC_LIGHTSLATEGRAY
Quantity_NOC_LIGHTSTEELBLUE = _Quantity.Quantity_NOC_LIGHTSTEELBLUE
Quantity_NOC_LIGHTSTEELBLUE1 = _Quantity.Quantity_NOC_LIGHTSTEELBLUE1
Quantity_NOC_LIGHTSTEELBLUE2 = _Quantity.Quantity_NOC_LIGHTSTEELBLUE2
Quantity_NOC_LIGHTSTEELBLUE3 = _Quantity.Quantity_NOC_LIGHTSTEELBLUE3
Quantity_NOC_LIGHTSTEELBLUE4 = _Quantity.Quantity_NOC_LIGHTSTEELBLUE4
Quantity_NOC_LIGHTYELLOW = _Quantity.Quantity_NOC_LIGHTYELLOW
Quantity_NOC_LIGHTYELLOW2 = _Quantity.Quantity_NOC_LIGHTYELLOW2
Quantity_NOC_LIGHTYELLOW3 = _Quantity.Quantity_NOC_LIGHTYELLOW3
Quantity_NOC_LIGHTYELLOW4 = _Quantity.Quantity_NOC_LIGHTYELLOW4
Quantity_NOC_LIMEGREEN = _Quantity.Quantity_NOC_LIMEGREEN
Quantity_NOC_LINEN = _Quantity.Quantity_NOC_LINEN
Quantity_NOC_MAGENTA = _Quantity.Quantity_NOC_MAGENTA
Quantity_NOC_MAGENTA1 = _Quantity.Quantity_NOC_MAGENTA1
Quantity_NOC_MAGENTA2 = _Quantity.Quantity_NOC_MAGENTA2
Quantity_NOC_MAGENTA3 = _Quantity.Quantity_NOC_MAGENTA3
Quantity_NOC_MAGENTA4 = _Quantity.Quantity_NOC_MAGENTA4
Quantity_NOC_MAROON = _Quantity.Quantity_NOC_MAROON
Quantity_NOC_MAROON1 = _Quantity.Quantity_NOC_MAROON1
Quantity_NOC_MAROON2 = _Quantity.Quantity_NOC_MAROON2
Quantity_NOC_MAROON3 = _Quantity.Quantity_NOC_MAROON3
Quantity_NOC_MAROON4 = _Quantity.Quantity_NOC_MAROON4
Quantity_NOC_MEDIUMAQUAMARINE = _Quantity.Quantity_NOC_MEDIUMAQUAMARINE
Quantity_NOC_MEDIUMORCHID = _Quantity.Quantity_NOC_MEDIUMORCHID
Quantity_NOC_MEDIUMORCHID1 = _Quantity.Quantity_NOC_MEDIUMORCHID1
Quantity_NOC_MEDIUMORCHID2 = _Quantity.Quantity_NOC_MEDIUMORCHID2
Quantity_NOC_MEDIUMORCHID3 = _Quantity.Quantity_NOC_MEDIUMORCHID3
Quantity_NOC_MEDIUMORCHID4 = _Quantity.Quantity_NOC_MEDIUMORCHID4
Quantity_NOC_MEDIUMPURPLE = _Quantity.Quantity_NOC_MEDIUMPURPLE
Quantity_NOC_MEDIUMPURPLE1 = _Quantity.Quantity_NOC_MEDIUMPURPLE1
Quantity_NOC_MEDIUMPURPLE2 = _Quantity.Quantity_NOC_MEDIUMPURPLE2
Quantity_NOC_MEDIUMPURPLE3 = _Quantity.Quantity_NOC_MEDIUMPURPLE3
Quantity_NOC_MEDIUMPURPLE4 = _Quantity.Quantity_NOC_MEDIUMPURPLE4
Quantity_NOC_MEDIUMSEAGREEN = _Quantity.Quantity_NOC_MEDIUMSEAGREEN
Quantity_NOC_MEDIUMSLATEBLUE = _Quantity.Quantity_NOC_MEDIUMSLATEBLUE
Quantity_NOC_MEDIUMSPRINGGREEN = _Quantity.Quantity_NOC_MEDIUMSPRINGGREEN
Quantity_NOC_MEDIUMTURQUOISE = _Quantity.Quantity_NOC_MEDIUMTURQUOISE
Quantity_NOC_MEDIUMVIOLETRED = _Quantity.Quantity_NOC_MEDIUMVIOLETRED
Quantity_NOC_MIDNIGHTBLUE = _Quantity.Quantity_NOC_MIDNIGHTBLUE
Quantity_NOC_MINTCREAM = _Quantity.Quantity_NOC_MINTCREAM
Quantity_NOC_MISTYROSE = _Quantity.Quantity_NOC_MISTYROSE
Quantity_NOC_MISTYROSE2 = _Quantity.Quantity_NOC_MISTYROSE2
Quantity_NOC_MISTYROSE3 = _Quantity.Quantity_NOC_MISTYROSE3
Quantity_NOC_MISTYROSE4 = _Quantity.Quantity_NOC_MISTYROSE4
Quantity_NOC_MOCCASIN = _Quantity.Quantity_NOC_MOCCASIN
Quantity_NOC_NAVAJOWHITE1 = _Quantity.Quantity_NOC_NAVAJOWHITE1
Quantity_NOC_NAVAJOWHITE2 = _Quantity.Quantity_NOC_NAVAJOWHITE2
Quantity_NOC_NAVAJOWHITE3 = _Quantity.Quantity_NOC_NAVAJOWHITE3
Quantity_NOC_NAVAJOWHITE4 = _Quantity.Quantity_NOC_NAVAJOWHITE4
Quantity_NOC_NAVYBLUE = _Quantity.Quantity_NOC_NAVYBLUE
Quantity_NOC_OLDLACE = _Quantity.Quantity_NOC_OLDLACE
Quantity_NOC_OLIVEDRAB = _Quantity.Quantity_NOC_OLIVEDRAB
Quantity_NOC_OLIVEDRAB1 = _Quantity.Quantity_NOC_OLIVEDRAB1
Quantity_NOC_OLIVEDRAB2 = _Quantity.Quantity_NOC_OLIVEDRAB2
Quantity_NOC_OLIVEDRAB3 = _Quantity.Quantity_NOC_OLIVEDRAB3
Quantity_NOC_OLIVEDRAB4 = _Quantity.Quantity_NOC_OLIVEDRAB4
Quantity_NOC_ORANGE = _Quantity.Quantity_NOC_ORANGE
Quantity_NOC_ORANGE1 = _Quantity.Quantity_NOC_ORANGE1
Quantity_NOC_ORANGE2 = _Quantity.Quantity_NOC_ORANGE2
Quantity_NOC_ORANGE3 = _Quantity.Quantity_NOC_ORANGE3
Quantity_NOC_ORANGE4 = _Quantity.Quantity_NOC_ORANGE4
Quantity_NOC_ORANGERED = _Quantity.Quantity_NOC_ORANGERED
Quantity_NOC_ORANGERED1 = _Quantity.Quantity_NOC_ORANGERED1
Quantity_NOC_ORANGERED2 = _Quantity.Quantity_NOC_ORANGERED2
Quantity_NOC_ORANGERED3 = _Quantity.Quantity_NOC_ORANGERED3
Quantity_NOC_ORANGERED4 = _Quantity.Quantity_NOC_ORANGERED4
Quantity_NOC_ORCHID = _Quantity.Quantity_NOC_ORCHID
Quantity_NOC_ORCHID1 = _Quantity.Quantity_NOC_ORCHID1
Quantity_NOC_ORCHID2 = _Quantity.Quantity_NOC_ORCHID2
Quantity_NOC_ORCHID3 = _Quantity.Quantity_NOC_ORCHID3
Quantity_NOC_ORCHID4 = _Quantity.Quantity_NOC_ORCHID4
Quantity_NOC_PALEGOLDENROD = _Quantity.Quantity_NOC_PALEGOLDENROD
Quantity_NOC_PALEGREEN = _Quantity.Quantity_NOC_PALEGREEN
Quantity_NOC_PALEGREEN1 = _Quantity.Quantity_NOC_PALEGREEN1
Quantity_NOC_PALEGREEN2 = _Quantity.Quantity_NOC_PALEGREEN2
Quantity_NOC_PALEGREEN3 = _Quantity.Quantity_NOC_PALEGREEN3
Quantity_NOC_PALEGREEN4 = _Quantity.Quantity_NOC_PALEGREEN4
Quantity_NOC_PALETURQUOISE = _Quantity.Quantity_NOC_PALETURQUOISE
Quantity_NOC_PALETURQUOISE1 = _Quantity.Quantity_NOC_PALETURQUOISE1
Quantity_NOC_PALETURQUOISE2 = _Quantity.Quantity_NOC_PALETURQUOISE2
Quantity_NOC_PALETURQUOISE3 = _Quantity.Quantity_NOC_PALETURQUOISE3
Quantity_NOC_PALETURQUOISE4 = _Quantity.Quantity_NOC_PALETURQUOISE4
Quantity_NOC_PALEVIOLETRED = _Quantity.Quantity_NOC_PALEVIOLETRED
Quantity_NOC_PALEVIOLETRED1 = _Quantity.Quantity_NOC_PALEVIOLETRED1
Quantity_NOC_PALEVIOLETRED2 = _Quantity.Quantity_NOC_PALEVIOLETRED2
Quantity_NOC_PALEVIOLETRED3 = _Quantity.Quantity_NOC_PALEVIOLETRED3
Quantity_NOC_PALEVIOLETRED4 = _Quantity.Quantity_NOC_PALEVIOLETRED4
Quantity_NOC_PAPAYAWHIP = _Quantity.Quantity_NOC_PAPAYAWHIP
Quantity_NOC_PEACHPUFF = _Quantity.Quantity_NOC_PEACHPUFF
Quantity_NOC_PEACHPUFF2 = _Quantity.Quantity_NOC_PEACHPUFF2
Quantity_NOC_PEACHPUFF3 = _Quantity.Quantity_NOC_PEACHPUFF3
Quantity_NOC_PEACHPUFF4 = _Quantity.Quantity_NOC_PEACHPUFF4
Quantity_NOC_PERU = _Quantity.Quantity_NOC_PERU
Quantity_NOC_PINK = _Quantity.Quantity_NOC_PINK
Quantity_NOC_PINK1 = _Quantity.Quantity_NOC_PINK1
Quantity_NOC_PINK2 = _Quantity.Quantity_NOC_PINK2
Quantity_NOC_PINK3 = _Quantity.Quantity_NOC_PINK3
Quantity_NOC_PINK4 = _Quantity.Quantity_NOC_PINK4
Quantity_NOC_PLUM = _Quantity.Quantity_NOC_PLUM
Quantity_NOC_PLUM1 = _Quantity.Quantity_NOC_PLUM1
Quantity_NOC_PLUM2 = _Quantity.Quantity_NOC_PLUM2
Quantity_NOC_PLUM3 = _Quantity.Quantity_NOC_PLUM3
Quantity_NOC_PLUM4 = _Quantity.Quantity_NOC_PLUM4
Quantity_NOC_POWDERBLUE = _Quantity.Quantity_NOC_POWDERBLUE
Quantity_NOC_PURPLE = _Quantity.Quantity_NOC_PURPLE
Quantity_NOC_PURPLE1 = _Quantity.Quantity_NOC_PURPLE1
Quantity_NOC_PURPLE2 = _Quantity.Quantity_NOC_PURPLE2
Quantity_NOC_PURPLE3 = _Quantity.Quantity_NOC_PURPLE3
Quantity_NOC_PURPLE4 = _Quantity.Quantity_NOC_PURPLE4
Quantity_NOC_RED = _Quantity.Quantity_NOC_RED
Quantity_NOC_RED1 = _Quantity.Quantity_NOC_RED1
Quantity_NOC_RED2 = _Quantity.Quantity_NOC_RED2
Quantity_NOC_RED3 = _Quantity.Quantity_NOC_RED3
Quantity_NOC_RED4 = _Quantity.Quantity_NOC_RED4
Quantity_NOC_ROSYBROWN = _Quantity.Quantity_NOC_ROSYBROWN
Quantity_NOC_ROSYBROWN1 = _Quantity.Quantity_NOC_ROSYBROWN1
Quantity_NOC_ROSYBROWN2 = _Quantity.Quantity_NOC_ROSYBROWN2
Quantity_NOC_ROSYBROWN3 = _Quantity.Quantity_NOC_ROSYBROWN3
Quantity_NOC_ROSYBROWN4 = _Quantity.Quantity_NOC_ROSYBROWN4
Quantity_NOC_ROYALBLUE = _Quantity.Quantity_NOC_ROYALBLUE
Quantity_NOC_ROYALBLUE1 = _Quantity.Quantity_NOC_ROYALBLUE1
Quantity_NOC_ROYALBLUE2 = _Quantity.Quantity_NOC_ROYALBLUE2
Quantity_NOC_ROYALBLUE3 = _Quantity.Quantity_NOC_ROYALBLUE3
Quantity_NOC_ROYALBLUE4 = _Quantity.Quantity_NOC_ROYALBLUE4
Quantity_NOC_SADDLEBROWN = _Quantity.Quantity_NOC_SADDLEBROWN
Quantity_NOC_SALMON = _Quantity.Quantity_NOC_SALMON
Quantity_NOC_SALMON1 = _Quantity.Quantity_NOC_SALMON1
Quantity_NOC_SALMON2 = _Quantity.Quantity_NOC_SALMON2
Quantity_NOC_SALMON3 = _Quantity.Quantity_NOC_SALMON3
Quantity_NOC_SALMON4 = _Quantity.Quantity_NOC_SALMON4
Quantity_NOC_SANDYBROWN = _Quantity.Quantity_NOC_SANDYBROWN
Quantity_NOC_SEAGREEN = _Quantity.Quantity_NOC_SEAGREEN
Quantity_NOC_SEAGREEN1 = _Quantity.Quantity_NOC_SEAGREEN1
Quantity_NOC_SEAGREEN2 = _Quantity.Quantity_NOC_SEAGREEN2
Quantity_NOC_SEAGREEN3 = _Quantity.Quantity_NOC_SEAGREEN3
Quantity_NOC_SEAGREEN4 = _Quantity.Quantity_NOC_SEAGREEN4
Quantity_NOC_SEASHELL = _Quantity.Quantity_NOC_SEASHELL
Quantity_NOC_SEASHELL2 = _Quantity.Quantity_NOC_SEASHELL2
Quantity_NOC_SEASHELL3 = _Quantity.Quantity_NOC_SEASHELL3
Quantity_NOC_SEASHELL4 = _Quantity.Quantity_NOC_SEASHELL4
Quantity_NOC_BEET = _Quantity.Quantity_NOC_BEET
Quantity_NOC_TEAL = _Quantity.Quantity_NOC_TEAL
Quantity_NOC_SIENNA = _Quantity.Quantity_NOC_SIENNA
Quantity_NOC_SIENNA1 = _Quantity.Quantity_NOC_SIENNA1
Quantity_NOC_SIENNA2 = _Quantity.Quantity_NOC_SIENNA2
Quantity_NOC_SIENNA3 = _Quantity.Quantity_NOC_SIENNA3
Quantity_NOC_SIENNA4 = _Quantity.Quantity_NOC_SIENNA4
Quantity_NOC_SKYBLUE = _Quantity.Quantity_NOC_SKYBLUE
Quantity_NOC_SKYBLUE1 = _Quantity.Quantity_NOC_SKYBLUE1
Quantity_NOC_SKYBLUE2 = _Quantity.Quantity_NOC_SKYBLUE2
Quantity_NOC_SKYBLUE3 = _Quantity.Quantity_NOC_SKYBLUE3
Quantity_NOC_SKYBLUE4 = _Quantity.Quantity_NOC_SKYBLUE4
Quantity_NOC_SLATEBLUE = _Quantity.Quantity_NOC_SLATEBLUE
Quantity_NOC_SLATEBLUE1 = _Quantity.Quantity_NOC_SLATEBLUE1
Quantity_NOC_SLATEBLUE2 = _Quantity.Quantity_NOC_SLATEBLUE2
Quantity_NOC_SLATEBLUE3 = _Quantity.Quantity_NOC_SLATEBLUE3
Quantity_NOC_SLATEBLUE4 = _Quantity.Quantity_NOC_SLATEBLUE4
Quantity_NOC_SLATEGRAY1 = _Quantity.Quantity_NOC_SLATEGRAY1
Quantity_NOC_SLATEGRAY2 = _Quantity.Quantity_NOC_SLATEGRAY2
Quantity_NOC_SLATEGRAY3 = _Quantity.Quantity_NOC_SLATEGRAY3
Quantity_NOC_SLATEGRAY4 = _Quantity.Quantity_NOC_SLATEGRAY4
Quantity_NOC_SLATEGRAY = _Quantity.Quantity_NOC_SLATEGRAY
Quantity_NOC_SNOW = _Quantity.Quantity_NOC_SNOW
Quantity_NOC_SNOW2 = _Quantity.Quantity_NOC_SNOW2
Quantity_NOC_SNOW3 = _Quantity.Quantity_NOC_SNOW3
Quantity_NOC_SNOW4 = _Quantity.Quantity_NOC_SNOW4
Quantity_NOC_SPRINGGREEN = _Quantity.Quantity_NOC_SPRINGGREEN
Quantity_NOC_SPRINGGREEN2 = _Quantity.Quantity_NOC_SPRINGGREEN2
Quantity_NOC_SPRINGGREEN3 = _Quantity.Quantity_NOC_SPRINGGREEN3
Quantity_NOC_SPRINGGREEN4 = _Quantity.Quantity_NOC_SPRINGGREEN4
Quantity_NOC_STEELBLUE = _Quantity.Quantity_NOC_STEELBLUE
Quantity_NOC_STEELBLUE1 = _Quantity.Quantity_NOC_STEELBLUE1
Quantity_NOC_STEELBLUE2 = _Quantity.Quantity_NOC_STEELBLUE2
Quantity_NOC_STEELBLUE3 = _Quantity.Quantity_NOC_STEELBLUE3
Quantity_NOC_STEELBLUE4 = _Quantity.Quantity_NOC_STEELBLUE4
Quantity_NOC_TAN = _Quantity.Quantity_NOC_TAN
Quantity_NOC_TAN1 = _Quantity.Quantity_NOC_TAN1
Quantity_NOC_TAN2 = _Quantity.Quantity_NOC_TAN2
Quantity_NOC_TAN3 = _Quantity.Quantity_NOC_TAN3
Quantity_NOC_TAN4 = _Quantity.Quantity_NOC_TAN4
Quantity_NOC_THISTLE = _Quantity.Quantity_NOC_THISTLE
Quantity_NOC_THISTLE1 = _Quantity.Quantity_NOC_THISTLE1
Quantity_NOC_THISTLE2 = _Quantity.Quantity_NOC_THISTLE2
Quantity_NOC_THISTLE3 = _Quantity.Quantity_NOC_THISTLE3
Quantity_NOC_THISTLE4 = _Quantity.Quantity_NOC_THISTLE4
Quantity_NOC_TOMATO = _Quantity.Quantity_NOC_TOMATO
Quantity_NOC_TOMATO1 = _Quantity.Quantity_NOC_TOMATO1
Quantity_NOC_TOMATO2 = _Quantity.Quantity_NOC_TOMATO2
Quantity_NOC_TOMATO3 = _Quantity.Quantity_NOC_TOMATO3
Quantity_NOC_TOMATO4 = _Quantity.Quantity_NOC_TOMATO4
Quantity_NOC_TURQUOISE = _Quantity.Quantity_NOC_TURQUOISE
Quantity_NOC_TURQUOISE1 = _Quantity.Quantity_NOC_TURQUOISE1
Quantity_NOC_TURQUOISE2 = _Quantity.Quantity_NOC_TURQUOISE2
Quantity_NOC_TURQUOISE3 = _Quantity.Quantity_NOC_TURQUOISE3
Quantity_NOC_TURQUOISE4 = _Quantity.Quantity_NOC_TURQUOISE4
Quantity_NOC_VIOLET = _Quantity.Quantity_NOC_VIOLET
Quantity_NOC_VIOLETRED = _Quantity.Quantity_NOC_VIOLETRED
Quantity_NOC_VIOLETRED1 = _Quantity.Quantity_NOC_VIOLETRED1
Quantity_NOC_VIOLETRED2 = _Quantity.Quantity_NOC_VIOLETRED2
Quantity_NOC_VIOLETRED3 = _Quantity.Quantity_NOC_VIOLETRED3
Quantity_NOC_VIOLETRED4 = _Quantity.Quantity_NOC_VIOLETRED4
Quantity_NOC_WHEAT = _Quantity.Quantity_NOC_WHEAT
Quantity_NOC_WHEAT1 = _Quantity.Quantity_NOC_WHEAT1
Quantity_NOC_WHEAT2 = _Quantity.Quantity_NOC_WHEAT2
Quantity_NOC_WHEAT3 = _Quantity.Quantity_NOC_WHEAT3
Quantity_NOC_WHEAT4 = _Quantity.Quantity_NOC_WHEAT4
Quantity_NOC_WHITESMOKE = _Quantity.Quantity_NOC_WHITESMOKE
Quantity_NOC_YELLOW = _Quantity.Quantity_NOC_YELLOW
Quantity_NOC_YELLOW1 = _Quantity.Quantity_NOC_YELLOW1
Quantity_NOC_YELLOW2 = _Quantity.Quantity_NOC_YELLOW2
Quantity_NOC_YELLOW3 = _Quantity.Quantity_NOC_YELLOW3
Quantity_NOC_YELLOW4 = _Quantity.Quantity_NOC_YELLOW4
Quantity_NOC_YELLOWGREEN = _Quantity.Quantity_NOC_YELLOWGREEN
Quantity_NOC_WHITE = _Quantity.Quantity_NOC_WHITE
Quantity_TOC_RGB = _Quantity.Quantity_TOC_RGB
Quantity_TOC_sRGB = _Quantity.Quantity_TOC_sRGB
Quantity_TOC_HLS = _Quantity.Quantity_TOC_HLS
Quantity_TOC_CIELab = _Quantity.Quantity_TOC_CIELab
Quantity_TOC_CIELch = _Quantity.Quantity_TOC_CIELch


class Quantity_NameOfColor(IntEnum):
	Quantity_NOC_BLACK = 0
	Quantity_NOC_MATRABLUE = 1
	Quantity_NOC_MATRAGRAY = 2
	Quantity_NOC_ALICEBLUE = 3
	Quantity_NOC_ANTIQUEWHITE = 4
	Quantity_NOC_ANTIQUEWHITE1 = 5
	Quantity_NOC_ANTIQUEWHITE2 = 6
	Quantity_NOC_ANTIQUEWHITE3 = 7
	Quantity_NOC_ANTIQUEWHITE4 = 8
	Quantity_NOC_AQUAMARINE1 = 9
	Quantity_NOC_AQUAMARINE2 = 10
	Quantity_NOC_AQUAMARINE4 = 11
	Quantity_NOC_AZURE = 12
	Quantity_NOC_AZURE2 = 13
	Quantity_NOC_AZURE3 = 14
	Quantity_NOC_AZURE4 = 15
	Quantity_NOC_BEIGE = 16
	Quantity_NOC_BISQUE = 17
	Quantity_NOC_BISQUE2 = 18
	Quantity_NOC_BISQUE3 = 19
	Quantity_NOC_BISQUE4 = 20
	Quantity_NOC_BLANCHEDALMOND = 21
	Quantity_NOC_BLUE = 22
	Quantity_NOC_BLUE1 = Quantity_NOC_BLUE
	Quantity_NOC_BLUE2 = 23
	Quantity_NOC_BLUE3 = 24
	Quantity_NOC_BLUE4 = 25
	Quantity_NOC_BLUEVIOLET = 26
	Quantity_NOC_BROWN = 27
	Quantity_NOC_BROWN1 = 28
	Quantity_NOC_BROWN2 = 29
	Quantity_NOC_BROWN3 = 30
	Quantity_NOC_BROWN4 = 31
	Quantity_NOC_BURLYWOOD = 32
	Quantity_NOC_BURLYWOOD1 = 33
	Quantity_NOC_BURLYWOOD2 = 34
	Quantity_NOC_BURLYWOOD3 = 35
	Quantity_NOC_BURLYWOOD4 = 36
	Quantity_NOC_CADETBLUE = 37
	Quantity_NOC_CADETBLUE1 = 38
	Quantity_NOC_CADETBLUE2 = 39
	Quantity_NOC_CADETBLUE3 = 40
	Quantity_NOC_CADETBLUE4 = 41
	Quantity_NOC_CHARTREUSE = 42
	Quantity_NOC_CHARTREUSE1 = Quantity_NOC_CHARTREUSE
	Quantity_NOC_CHARTREUSE2 = 43
	Quantity_NOC_CHARTREUSE3 = 44
	Quantity_NOC_CHARTREUSE4 = 45
	Quantity_NOC_CHOCOLATE = 46
	Quantity_NOC_CHOCOLATE1 = 47
	Quantity_NOC_CHOCOLATE2 = 48
	Quantity_NOC_CHOCOLATE3 = 49
	Quantity_NOC_CHOCOLATE4 = 50
	Quantity_NOC_CORAL = 51
	Quantity_NOC_CORAL1 = 52
	Quantity_NOC_CORAL2 = 53
	Quantity_NOC_CORAL3 = 54
	Quantity_NOC_CORAL4 = 55
	Quantity_NOC_CORNFLOWERBLUE = 56
	Quantity_NOC_CORNSILK1 = 57
	Quantity_NOC_CORNSILK2 = 58
	Quantity_NOC_CORNSILK3 = 59
	Quantity_NOC_CORNSILK4 = 60
	Quantity_NOC_CYAN = 61
	Quantity_NOC_CYAN1 = Quantity_NOC_CYAN
	Quantity_NOC_CYAN2 = 62
	Quantity_NOC_CYAN3 = 63
	Quantity_NOC_CYAN4 = 64
	Quantity_NOC_DARKGOLDENROD = 65
	Quantity_NOC_DARKGOLDENROD1 = 66
	Quantity_NOC_DARKGOLDENROD2 = 67
	Quantity_NOC_DARKGOLDENROD3 = 68
	Quantity_NOC_DARKGOLDENROD4 = 69
	Quantity_NOC_DARKGREEN = 70
	Quantity_NOC_DARKKHAKI = 71
	Quantity_NOC_DARKOLIVEGREEN = 72
	Quantity_NOC_DARKOLIVEGREEN1 = 73
	Quantity_NOC_DARKOLIVEGREEN2 = 74
	Quantity_NOC_DARKOLIVEGREEN3 = 75
	Quantity_NOC_DARKOLIVEGREEN4 = 76
	Quantity_NOC_DARKORANGE = 77
	Quantity_NOC_DARKORANGE1 = 78
	Quantity_NOC_DARKORANGE2 = 79
	Quantity_NOC_DARKORANGE3 = 80
	Quantity_NOC_DARKORANGE4 = 81
	Quantity_NOC_DARKORCHID = 82
	Quantity_NOC_DARKORCHID1 = 83
	Quantity_NOC_DARKORCHID2 = 84
	Quantity_NOC_DARKORCHID3 = 85
	Quantity_NOC_DARKORCHID4 = 86
	Quantity_NOC_DARKSALMON = 87
	Quantity_NOC_DARKSEAGREEN = 88
	Quantity_NOC_DARKSEAGREEN1 = 89
	Quantity_NOC_DARKSEAGREEN2 = 90
	Quantity_NOC_DARKSEAGREEN3 = 91
	Quantity_NOC_DARKSEAGREEN4 = 92
	Quantity_NOC_DARKSLATEBLUE = 93
	Quantity_NOC_DARKSLATEGRAY1 = 94
	Quantity_NOC_DARKSLATEGRAY2 = 95
	Quantity_NOC_DARKSLATEGRAY3 = 96
	Quantity_NOC_DARKSLATEGRAY4 = 97
	Quantity_NOC_DARKSLATEGRAY = 98
	Quantity_NOC_DARKTURQUOISE = 99
	Quantity_NOC_DARKVIOLET = 100
	Quantity_NOC_DEEPPINK = 101
	Quantity_NOC_DEEPPINK2 = 102
	Quantity_NOC_DEEPPINK3 = 103
	Quantity_NOC_DEEPPINK4 = 104
	Quantity_NOC_DEEPSKYBLUE1 = 105
	Quantity_NOC_DEEPSKYBLUE2 = 106
	Quantity_NOC_DEEPSKYBLUE3 = 107
	Quantity_NOC_DEEPSKYBLUE4 = 108
	Quantity_NOC_DODGERBLUE1 = 109
	Quantity_NOC_DODGERBLUE2 = 110
	Quantity_NOC_DODGERBLUE3 = 111
	Quantity_NOC_DODGERBLUE4 = 112
	Quantity_NOC_FIREBRICK = 113
	Quantity_NOC_FIREBRICK1 = 114
	Quantity_NOC_FIREBRICK2 = 115
	Quantity_NOC_FIREBRICK3 = 116
	Quantity_NOC_FIREBRICK4 = 117
	Quantity_NOC_FLORALWHITE = 118
	Quantity_NOC_FORESTGREEN = 119
	Quantity_NOC_GAINSBORO = 120
	Quantity_NOC_GHOSTWHITE = 121
	Quantity_NOC_GOLD = 122
	Quantity_NOC_GOLD1 = Quantity_NOC_GOLD
	Quantity_NOC_GOLD2 = 123
	Quantity_NOC_GOLD3 = 124
	Quantity_NOC_GOLD4 = 125
	Quantity_NOC_GOLDENROD = 126
	Quantity_NOC_GOLDENROD1 = 127
	Quantity_NOC_GOLDENROD2 = 128
	Quantity_NOC_GOLDENROD3 = 129
	Quantity_NOC_GOLDENROD4 = 130
	Quantity_NOC_GRAY = 131
	Quantity_NOC_GRAY0 = 132
	Quantity_NOC_GRAY1 = 133
	Quantity_NOC_GRAY2 = 134
	Quantity_NOC_GRAY3 = 135
	Quantity_NOC_GRAY4 = 136
	Quantity_NOC_GRAY5 = 137
	Quantity_NOC_GRAY6 = 138
	Quantity_NOC_GRAY7 = 139
	Quantity_NOC_GRAY8 = 140
	Quantity_NOC_GRAY9 = 141
	Quantity_NOC_GRAY10 = 142
	Quantity_NOC_GRAY11 = 143
	Quantity_NOC_GRAY12 = 144
	Quantity_NOC_GRAY13 = 145
	Quantity_NOC_GRAY14 = 146
	Quantity_NOC_GRAY15 = 147
	Quantity_NOC_GRAY16 = 148
	Quantity_NOC_GRAY17 = 149
	Quantity_NOC_GRAY18 = 150
	Quantity_NOC_GRAY19 = 151
	Quantity_NOC_GRAY20 = 152
	Quantity_NOC_GRAY21 = 153
	Quantity_NOC_GRAY22 = 154
	Quantity_NOC_GRAY23 = 155
	Quantity_NOC_GRAY24 = 156
	Quantity_NOC_GRAY25 = 157
	Quantity_NOC_GRAY26 = 158
	Quantity_NOC_GRAY27 = 159
	Quantity_NOC_GRAY28 = 160
	Quantity_NOC_GRAY29 = 161
	Quantity_NOC_GRAY30 = 162
	Quantity_NOC_GRAY31 = 163
	Quantity_NOC_GRAY32 = 164
	Quantity_NOC_GRAY33 = 165
	Quantity_NOC_GRAY34 = 166
	Quantity_NOC_GRAY35 = 167
	Quantity_NOC_GRAY36 = 168
	Quantity_NOC_GRAY37 = 169
	Quantity_NOC_GRAY38 = 170
	Quantity_NOC_GRAY39 = 171
	Quantity_NOC_GRAY40 = 172
	Quantity_NOC_GRAY41 = 173
	Quantity_NOC_GRAY42 = 174
	Quantity_NOC_GRAY43 = 175
	Quantity_NOC_GRAY44 = 176
	Quantity_NOC_GRAY45 = 177
	Quantity_NOC_GRAY46 = 178
	Quantity_NOC_GRAY47 = 179
	Quantity_NOC_GRAY48 = 180
	Quantity_NOC_GRAY49 = 181
	Quantity_NOC_GRAY50 = 182
	Quantity_NOC_GRAY51 = 183
	Quantity_NOC_GRAY52 = 184
	Quantity_NOC_GRAY53 = 185
	Quantity_NOC_GRAY54 = 186
	Quantity_NOC_GRAY55 = 187
	Quantity_NOC_GRAY56 = 188
	Quantity_NOC_GRAY57 = 189
	Quantity_NOC_GRAY58 = 190
	Quantity_NOC_GRAY59 = 191
	Quantity_NOC_GRAY60 = 192
	Quantity_NOC_GRAY61 = 193
	Quantity_NOC_GRAY62 = 194
	Quantity_NOC_GRAY63 = 195
	Quantity_NOC_GRAY64 = 196
	Quantity_NOC_GRAY65 = 197
	Quantity_NOC_GRAY66 = 198
	Quantity_NOC_GRAY67 = 199
	Quantity_NOC_GRAY68 = 200
	Quantity_NOC_GRAY69 = 201
	Quantity_NOC_GRAY70 = 202
	Quantity_NOC_GRAY71 = 203
	Quantity_NOC_GRAY72 = 204
	Quantity_NOC_GRAY73 = 205
	Quantity_NOC_GRAY74 = 206
	Quantity_NOC_GRAY75 = 207
	Quantity_NOC_GRAY76 = 208
	Quantity_NOC_GRAY77 = 209
	Quantity_NOC_GRAY78 = 210
	Quantity_NOC_GRAY79 = 211
	Quantity_NOC_GRAY80 = 212
	Quantity_NOC_GRAY81 = 213
	Quantity_NOC_GRAY82 = 214
	Quantity_NOC_GRAY83 = 215
	Quantity_NOC_GRAY85 = 216
	Quantity_NOC_GRAY86 = 217
	Quantity_NOC_GRAY87 = 218
	Quantity_NOC_GRAY88 = 219
	Quantity_NOC_GRAY89 = 220
	Quantity_NOC_GRAY90 = 221
	Quantity_NOC_GRAY91 = 222
	Quantity_NOC_GRAY92 = 223
	Quantity_NOC_GRAY93 = 224
	Quantity_NOC_GRAY94 = 225
	Quantity_NOC_GRAY95 = 226
	Quantity_NOC_GRAY97 = 227
	Quantity_NOC_GRAY98 = 228
	Quantity_NOC_GRAY99 = 229
	Quantity_NOC_GREEN = 230
	Quantity_NOC_GREEN1 = Quantity_NOC_GREEN
	Quantity_NOC_GREEN2 = 231
	Quantity_NOC_GREEN3 = 232
	Quantity_NOC_GREEN4 = 233
	Quantity_NOC_GREENYELLOW = 234
	Quantity_NOC_HONEYDEW = 235
	Quantity_NOC_HONEYDEW2 = 236
	Quantity_NOC_HONEYDEW3 = 237
	Quantity_NOC_HONEYDEW4 = 238
	Quantity_NOC_HOTPINK = 239
	Quantity_NOC_HOTPINK1 = 240
	Quantity_NOC_HOTPINK2 = 241
	Quantity_NOC_HOTPINK3 = 242
	Quantity_NOC_HOTPINK4 = 243
	Quantity_NOC_INDIANRED = 244
	Quantity_NOC_INDIANRED1 = 245
	Quantity_NOC_INDIANRED2 = 246
	Quantity_NOC_INDIANRED3 = 247
	Quantity_NOC_INDIANRED4 = 248
	Quantity_NOC_IVORY = 249
	Quantity_NOC_IVORY2 = 250
	Quantity_NOC_IVORY3 = 251
	Quantity_NOC_IVORY4 = 252
	Quantity_NOC_KHAKI = 253
	Quantity_NOC_KHAKI1 = 254
	Quantity_NOC_KHAKI2 = 255
	Quantity_NOC_KHAKI3 = 256
	Quantity_NOC_KHAKI4 = 257
	Quantity_NOC_LAVENDER = 258
	Quantity_NOC_LAVENDERBLUSH1 = 259
	Quantity_NOC_LAVENDERBLUSH2 = 260
	Quantity_NOC_LAVENDERBLUSH3 = 261
	Quantity_NOC_LAVENDERBLUSH4 = 262
	Quantity_NOC_LAWNGREEN = 263
	Quantity_NOC_LEMONCHIFFON1 = 264
	Quantity_NOC_LEMONCHIFFON2 = 265
	Quantity_NOC_LEMONCHIFFON3 = 266
	Quantity_NOC_LEMONCHIFFON4 = 267
	Quantity_NOC_LIGHTBLUE = 268
	Quantity_NOC_LIGHTBLUE1 = 269
	Quantity_NOC_LIGHTBLUE2 = 270
	Quantity_NOC_LIGHTBLUE3 = 271
	Quantity_NOC_LIGHTBLUE4 = 272
	Quantity_NOC_LIGHTCORAL = 273
	Quantity_NOC_LIGHTCYAN = 274
	Quantity_NOC_LIGHTCYAN1 = Quantity_NOC_LIGHTCYAN
	Quantity_NOC_LIGHTCYAN2 = 275
	Quantity_NOC_LIGHTCYAN3 = 276
	Quantity_NOC_LIGHTCYAN4 = 277
	Quantity_NOC_LIGHTGOLDENROD = 278
	Quantity_NOC_LIGHTGOLDENROD1 = 279
	Quantity_NOC_LIGHTGOLDENROD2 = 280
	Quantity_NOC_LIGHTGOLDENROD3 = 281
	Quantity_NOC_LIGHTGOLDENROD4 = 282
	Quantity_NOC_LIGHTGOLDENRODYELLOW = 283
	Quantity_NOC_LIGHTGRAY = 284
	Quantity_NOC_LIGHTPINK = 285
	Quantity_NOC_LIGHTPINK1 = 286
	Quantity_NOC_LIGHTPINK2 = 287
	Quantity_NOC_LIGHTPINK3 = 288
	Quantity_NOC_LIGHTPINK4 = 289
	Quantity_NOC_LIGHTSALMON1 = 290
	Quantity_NOC_LIGHTSALMON2 = 291
	Quantity_NOC_LIGHTSALMON3 = 292
	Quantity_NOC_LIGHTSALMON4 = 293
	Quantity_NOC_LIGHTSEAGREEN = 294
	Quantity_NOC_LIGHTSKYBLUE = 295
	Quantity_NOC_LIGHTSKYBLUE1 = 296
	Quantity_NOC_LIGHTSKYBLUE2 = 297
	Quantity_NOC_LIGHTSKYBLUE3 = 298
	Quantity_NOC_LIGHTSKYBLUE4 = 299
	Quantity_NOC_LIGHTSLATEBLUE = 300
	Quantity_NOC_LIGHTSLATEGRAY = 301
	Quantity_NOC_LIGHTSTEELBLUE = 302
	Quantity_NOC_LIGHTSTEELBLUE1 = 303
	Quantity_NOC_LIGHTSTEELBLUE2 = 304
	Quantity_NOC_LIGHTSTEELBLUE3 = 305
	Quantity_NOC_LIGHTSTEELBLUE4 = 306
	Quantity_NOC_LIGHTYELLOW = 307
	Quantity_NOC_LIGHTYELLOW2 = 308
	Quantity_NOC_LIGHTYELLOW3 = 309
	Quantity_NOC_LIGHTYELLOW4 = 310
	Quantity_NOC_LIMEGREEN = 311
	Quantity_NOC_LINEN = 312
	Quantity_NOC_MAGENTA = 313
	Quantity_NOC_MAGENTA1 = Quantity_NOC_MAGENTA
	Quantity_NOC_MAGENTA2 = 314
	Quantity_NOC_MAGENTA3 = 315
	Quantity_NOC_MAGENTA4 = 316
	Quantity_NOC_MAROON = 317
	Quantity_NOC_MAROON1 = 318
	Quantity_NOC_MAROON2 = 319
	Quantity_NOC_MAROON3 = 320
	Quantity_NOC_MAROON4 = 321
	Quantity_NOC_MEDIUMAQUAMARINE = 322
	Quantity_NOC_MEDIUMORCHID = 323
	Quantity_NOC_MEDIUMORCHID1 = 324
	Quantity_NOC_MEDIUMORCHID2 = 325
	Quantity_NOC_MEDIUMORCHID3 = 326
	Quantity_NOC_MEDIUMORCHID4 = 327
	Quantity_NOC_MEDIUMPURPLE = 328
	Quantity_NOC_MEDIUMPURPLE1 = 329
	Quantity_NOC_MEDIUMPURPLE2 = 330
	Quantity_NOC_MEDIUMPURPLE3 = 331
	Quantity_NOC_MEDIUMPURPLE4 = 332
	Quantity_NOC_MEDIUMSEAGREEN = 333
	Quantity_NOC_MEDIUMSLATEBLUE = 334
	Quantity_NOC_MEDIUMSPRINGGREEN = 335
	Quantity_NOC_MEDIUMTURQUOISE = 336
	Quantity_NOC_MEDIUMVIOLETRED = 337
	Quantity_NOC_MIDNIGHTBLUE = 338
	Quantity_NOC_MINTCREAM = 339
	Quantity_NOC_MISTYROSE = 340
	Quantity_NOC_MISTYROSE2 = 341
	Quantity_NOC_MISTYROSE3 = 342
	Quantity_NOC_MISTYROSE4 = 343
	Quantity_NOC_MOCCASIN = 344
	Quantity_NOC_NAVAJOWHITE1 = 345
	Quantity_NOC_NAVAJOWHITE2 = 346
	Quantity_NOC_NAVAJOWHITE3 = 347
	Quantity_NOC_NAVAJOWHITE4 = 348
	Quantity_NOC_NAVYBLUE = 349
	Quantity_NOC_OLDLACE = 350
	Quantity_NOC_OLIVEDRAB = 351
	Quantity_NOC_OLIVEDRAB1 = 352
	Quantity_NOC_OLIVEDRAB2 = 353
	Quantity_NOC_OLIVEDRAB3 = 354
	Quantity_NOC_OLIVEDRAB4 = 355
	Quantity_NOC_ORANGE = 356
	Quantity_NOC_ORANGE1 = Quantity_NOC_ORANGE
	Quantity_NOC_ORANGE2 = 357
	Quantity_NOC_ORANGE3 = 358
	Quantity_NOC_ORANGE4 = 359
	Quantity_NOC_ORANGERED = 360
	Quantity_NOC_ORANGERED1 = Quantity_NOC_ORANGERED
	Quantity_NOC_ORANGERED2 = 361
	Quantity_NOC_ORANGERED3 = 362
	Quantity_NOC_ORANGERED4 = 363
	Quantity_NOC_ORCHID = 364
	Quantity_NOC_ORCHID1 = 365
	Quantity_NOC_ORCHID2 = 366
	Quantity_NOC_ORCHID3 = 367
	Quantity_NOC_ORCHID4 = 368
	Quantity_NOC_PALEGOLDENROD = 369
	Quantity_NOC_PALEGREEN = 370
	Quantity_NOC_PALEGREEN1 = 371
	Quantity_NOC_PALEGREEN2 = 372
	Quantity_NOC_PALEGREEN3 = 373
	Quantity_NOC_PALEGREEN4 = 374
	Quantity_NOC_PALETURQUOISE = 375
	Quantity_NOC_PALETURQUOISE1 = 376
	Quantity_NOC_PALETURQUOISE2 = 377
	Quantity_NOC_PALETURQUOISE3 = 378
	Quantity_NOC_PALETURQUOISE4 = 379
	Quantity_NOC_PALEVIOLETRED = 380
	Quantity_NOC_PALEVIOLETRED1 = 381
	Quantity_NOC_PALEVIOLETRED2 = 382
	Quantity_NOC_PALEVIOLETRED3 = 383
	Quantity_NOC_PALEVIOLETRED4 = 384
	Quantity_NOC_PAPAYAWHIP = 385
	Quantity_NOC_PEACHPUFF = 386
	Quantity_NOC_PEACHPUFF2 = 387
	Quantity_NOC_PEACHPUFF3 = 388
	Quantity_NOC_PEACHPUFF4 = 389
	Quantity_NOC_PERU = 390
	Quantity_NOC_PINK = 391
	Quantity_NOC_PINK1 = 392
	Quantity_NOC_PINK2 = 393
	Quantity_NOC_PINK3 = 394
	Quantity_NOC_PINK4 = 395
	Quantity_NOC_PLUM = 396
	Quantity_NOC_PLUM1 = 397
	Quantity_NOC_PLUM2 = 398
	Quantity_NOC_PLUM3 = 399
	Quantity_NOC_PLUM4 = 400
	Quantity_NOC_POWDERBLUE = 401
	Quantity_NOC_PURPLE = 402
	Quantity_NOC_PURPLE1 = 403
	Quantity_NOC_PURPLE2 = 404
	Quantity_NOC_PURPLE3 = 405
	Quantity_NOC_PURPLE4 = 406
	Quantity_NOC_RED = 407
	Quantity_NOC_RED1 = Quantity_NOC_RED
	Quantity_NOC_RED2 = 408
	Quantity_NOC_RED3 = 409
	Quantity_NOC_RED4 = 410
	Quantity_NOC_ROSYBROWN = 411
	Quantity_NOC_ROSYBROWN1 = 412
	Quantity_NOC_ROSYBROWN2 = 413
	Quantity_NOC_ROSYBROWN3 = 414
	Quantity_NOC_ROSYBROWN4 = 415
	Quantity_NOC_ROYALBLUE = 416
	Quantity_NOC_ROYALBLUE1 = 417
	Quantity_NOC_ROYALBLUE2 = 418
	Quantity_NOC_ROYALBLUE3 = 419
	Quantity_NOC_ROYALBLUE4 = 420
	Quantity_NOC_SADDLEBROWN = 421
	Quantity_NOC_SALMON = 422
	Quantity_NOC_SALMON1 = 423
	Quantity_NOC_SALMON2 = 424
	Quantity_NOC_SALMON3 = 425
	Quantity_NOC_SALMON4 = 426
	Quantity_NOC_SANDYBROWN = 427
	Quantity_NOC_SEAGREEN = 428
	Quantity_NOC_SEAGREEN1 = 429
	Quantity_NOC_SEAGREEN2 = 430
	Quantity_NOC_SEAGREEN3 = 431
	Quantity_NOC_SEAGREEN4 = 432
	Quantity_NOC_SEASHELL = 433
	Quantity_NOC_SEASHELL2 = 434
	Quantity_NOC_SEASHELL3 = 435
	Quantity_NOC_SEASHELL4 = 436
	Quantity_NOC_BEET = 437
	Quantity_NOC_TEAL = 438
	Quantity_NOC_SIENNA = 439
	Quantity_NOC_SIENNA1 = 440
	Quantity_NOC_SIENNA2 = 441
	Quantity_NOC_SIENNA3 = 442
	Quantity_NOC_SIENNA4 = 443
	Quantity_NOC_SKYBLUE = 444
	Quantity_NOC_SKYBLUE1 = 445
	Quantity_NOC_SKYBLUE2 = 446
	Quantity_NOC_SKYBLUE3 = 447
	Quantity_NOC_SKYBLUE4 = 448
	Quantity_NOC_SLATEBLUE = 449
	Quantity_NOC_SLATEBLUE1 = 450
	Quantity_NOC_SLATEBLUE2 = 451
	Quantity_NOC_SLATEBLUE3 = 452
	Quantity_NOC_SLATEBLUE4 = 453
	Quantity_NOC_SLATEGRAY1 = 454
	Quantity_NOC_SLATEGRAY2 = 455
	Quantity_NOC_SLATEGRAY3 = 456
	Quantity_NOC_SLATEGRAY4 = 457
	Quantity_NOC_SLATEGRAY = 458
	Quantity_NOC_SNOW = 459
	Quantity_NOC_SNOW2 = 460
	Quantity_NOC_SNOW3 = 461
	Quantity_NOC_SNOW4 = 462
	Quantity_NOC_SPRINGGREEN = 463
	Quantity_NOC_SPRINGGREEN2 = 464
	Quantity_NOC_SPRINGGREEN3 = 465
	Quantity_NOC_SPRINGGREEN4 = 466
	Quantity_NOC_STEELBLUE = 467
	Quantity_NOC_STEELBLUE1 = 468
	Quantity_NOC_STEELBLUE2 = 469
	Quantity_NOC_STEELBLUE3 = 470
	Quantity_NOC_STEELBLUE4 = 471
	Quantity_NOC_TAN = 472
	Quantity_NOC_TAN1 = 473
	Quantity_NOC_TAN2 = 474
	Quantity_NOC_TAN3 = 475
	Quantity_NOC_TAN4 = 476
	Quantity_NOC_THISTLE = 477
	Quantity_NOC_THISTLE1 = 478
	Quantity_NOC_THISTLE2 = 479
	Quantity_NOC_THISTLE3 = 480
	Quantity_NOC_THISTLE4 = 481
	Quantity_NOC_TOMATO = 482
	Quantity_NOC_TOMATO1 = Quantity_NOC_TOMATO
	Quantity_NOC_TOMATO2 = 483
	Quantity_NOC_TOMATO3 = 484
	Quantity_NOC_TOMATO4 = 485
	Quantity_NOC_TURQUOISE = 486
	Quantity_NOC_TURQUOISE1 = 487
	Quantity_NOC_TURQUOISE2 = 488
	Quantity_NOC_TURQUOISE3 = 489
	Quantity_NOC_TURQUOISE4 = 490
	Quantity_NOC_VIOLET = 491
	Quantity_NOC_VIOLETRED = 492
	Quantity_NOC_VIOLETRED1 = 493
	Quantity_NOC_VIOLETRED2 = 494
	Quantity_NOC_VIOLETRED3 = 495
	Quantity_NOC_VIOLETRED4 = 496
	Quantity_NOC_WHEAT = 497
	Quantity_NOC_WHEAT1 = 498
	Quantity_NOC_WHEAT2 = 499
	Quantity_NOC_WHEAT3 = 500
	Quantity_NOC_WHEAT4 = 501
	Quantity_NOC_WHITESMOKE = 502
	Quantity_NOC_YELLOW = 503
	Quantity_NOC_YELLOW1 = Quantity_NOC_YELLOW
	Quantity_NOC_YELLOW2 = 504
	Quantity_NOC_YELLOW3 = 505
	Quantity_NOC_YELLOW4 = 506
	Quantity_NOC_YELLOWGREEN = 507
	Quantity_NOC_WHITE = 508
Quantity_NOC_BLACK = Quantity_NameOfColor.Quantity_NOC_BLACK
Quantity_NOC_MATRABLUE = Quantity_NameOfColor.Quantity_NOC_MATRABLUE
Quantity_NOC_MATRAGRAY = Quantity_NameOfColor.Quantity_NOC_MATRAGRAY
Quantity_NOC_ALICEBLUE = Quantity_NameOfColor.Quantity_NOC_ALICEBLUE
Quantity_NOC_ANTIQUEWHITE = Quantity_NameOfColor.Quantity_NOC_ANTIQUEWHITE
Quantity_NOC_ANTIQUEWHITE1 = Quantity_NameOfColor.Quantity_NOC_ANTIQUEWHITE1
Quantity_NOC_ANTIQUEWHITE2 = Quantity_NameOfColor.Quantity_NOC_ANTIQUEWHITE2
Quantity_NOC_ANTIQUEWHITE3 = Quantity_NameOfColor.Quantity_NOC_ANTIQUEWHITE3
Quantity_NOC_ANTIQUEWHITE4 = Quantity_NameOfColor.Quantity_NOC_ANTIQUEWHITE4
Quantity_NOC_AQUAMARINE1 = Quantity_NameOfColor.Quantity_NOC_AQUAMARINE1
Quantity_NOC_AQUAMARINE2 = Quantity_NameOfColor.Quantity_NOC_AQUAMARINE2
Quantity_NOC_AQUAMARINE4 = Quantity_NameOfColor.Quantity_NOC_AQUAMARINE4
Quantity_NOC_AZURE = Quantity_NameOfColor.Quantity_NOC_AZURE
Quantity_NOC_AZURE2 = Quantity_NameOfColor.Quantity_NOC_AZURE2
Quantity_NOC_AZURE3 = Quantity_NameOfColor.Quantity_NOC_AZURE3
Quantity_NOC_AZURE4 = Quantity_NameOfColor.Quantity_NOC_AZURE4
Quantity_NOC_BEIGE = Quantity_NameOfColor.Quantity_NOC_BEIGE
Quantity_NOC_BISQUE = Quantity_NameOfColor.Quantity_NOC_BISQUE
Quantity_NOC_BISQUE2 = Quantity_NameOfColor.Quantity_NOC_BISQUE2
Quantity_NOC_BISQUE3 = Quantity_NameOfColor.Quantity_NOC_BISQUE3
Quantity_NOC_BISQUE4 = Quantity_NameOfColor.Quantity_NOC_BISQUE4
Quantity_NOC_BLANCHEDALMOND = Quantity_NameOfColor.Quantity_NOC_BLANCHEDALMOND
Quantity_NOC_BLUE = Quantity_NameOfColor.Quantity_NOC_BLUE
Quantity_NOC_BLUE1 = Quantity_NameOfColor.Quantity_NOC_BLUE1
Quantity_NOC_BLUE2 = Quantity_NameOfColor.Quantity_NOC_BLUE2
Quantity_NOC_BLUE3 = Quantity_NameOfColor.Quantity_NOC_BLUE3
Quantity_NOC_BLUE4 = Quantity_NameOfColor.Quantity_NOC_BLUE4
Quantity_NOC_BLUEVIOLET = Quantity_NameOfColor.Quantity_NOC_BLUEVIOLET
Quantity_NOC_BROWN = Quantity_NameOfColor.Quantity_NOC_BROWN
Quantity_NOC_BROWN1 = Quantity_NameOfColor.Quantity_NOC_BROWN1
Quantity_NOC_BROWN2 = Quantity_NameOfColor.Quantity_NOC_BROWN2
Quantity_NOC_BROWN3 = Quantity_NameOfColor.Quantity_NOC_BROWN3
Quantity_NOC_BROWN4 = Quantity_NameOfColor.Quantity_NOC_BROWN4
Quantity_NOC_BURLYWOOD = Quantity_NameOfColor.Quantity_NOC_BURLYWOOD
Quantity_NOC_BURLYWOOD1 = Quantity_NameOfColor.Quantity_NOC_BURLYWOOD1
Quantity_NOC_BURLYWOOD2 = Quantity_NameOfColor.Quantity_NOC_BURLYWOOD2
Quantity_NOC_BURLYWOOD3 = Quantity_NameOfColor.Quantity_NOC_BURLYWOOD3
Quantity_NOC_BURLYWOOD4 = Quantity_NameOfColor.Quantity_NOC_BURLYWOOD4
Quantity_NOC_CADETBLUE = Quantity_NameOfColor.Quantity_NOC_CADETBLUE
Quantity_NOC_CADETBLUE1 = Quantity_NameOfColor.Quantity_NOC_CADETBLUE1
Quantity_NOC_CADETBLUE2 = Quantity_NameOfColor.Quantity_NOC_CADETBLUE2
Quantity_NOC_CADETBLUE3 = Quantity_NameOfColor.Quantity_NOC_CADETBLUE3
Quantity_NOC_CADETBLUE4 = Quantity_NameOfColor.Quantity_NOC_CADETBLUE4
Quantity_NOC_CHARTREUSE = Quantity_NameOfColor.Quantity_NOC_CHARTREUSE
Quantity_NOC_CHARTREUSE1 = Quantity_NameOfColor.Quantity_NOC_CHARTREUSE1
Quantity_NOC_CHARTREUSE2 = Quantity_NameOfColor.Quantity_NOC_CHARTREUSE2
Quantity_NOC_CHARTREUSE3 = Quantity_NameOfColor.Quantity_NOC_CHARTREUSE3
Quantity_NOC_CHARTREUSE4 = Quantity_NameOfColor.Quantity_NOC_CHARTREUSE4
Quantity_NOC_CHOCOLATE = Quantity_NameOfColor.Quantity_NOC_CHOCOLATE
Quantity_NOC_CHOCOLATE1 = Quantity_NameOfColor.Quantity_NOC_CHOCOLATE1
Quantity_NOC_CHOCOLATE2 = Quantity_NameOfColor.Quantity_NOC_CHOCOLATE2
Quantity_NOC_CHOCOLATE3 = Quantity_NameOfColor.Quantity_NOC_CHOCOLATE3
Quantity_NOC_CHOCOLATE4 = Quantity_NameOfColor.Quantity_NOC_CHOCOLATE4
Quantity_NOC_CORAL = Quantity_NameOfColor.Quantity_NOC_CORAL
Quantity_NOC_CORAL1 = Quantity_NameOfColor.Quantity_NOC_CORAL1
Quantity_NOC_CORAL2 = Quantity_NameOfColor.Quantity_NOC_CORAL2
Quantity_NOC_CORAL3 = Quantity_NameOfColor.Quantity_NOC_CORAL3
Quantity_NOC_CORAL4 = Quantity_NameOfColor.Quantity_NOC_CORAL4
Quantity_NOC_CORNFLOWERBLUE = Quantity_NameOfColor.Quantity_NOC_CORNFLOWERBLUE
Quantity_NOC_CORNSILK1 = Quantity_NameOfColor.Quantity_NOC_CORNSILK1
Quantity_NOC_CORNSILK2 = Quantity_NameOfColor.Quantity_NOC_CORNSILK2
Quantity_NOC_CORNSILK3 = Quantity_NameOfColor.Quantity_NOC_CORNSILK3
Quantity_NOC_CORNSILK4 = Quantity_NameOfColor.Quantity_NOC_CORNSILK4
Quantity_NOC_CYAN = Quantity_NameOfColor.Quantity_NOC_CYAN
Quantity_NOC_CYAN1 = Quantity_NameOfColor.Quantity_NOC_CYAN1
Quantity_NOC_CYAN2 = Quantity_NameOfColor.Quantity_NOC_CYAN2
Quantity_NOC_CYAN3 = Quantity_NameOfColor.Quantity_NOC_CYAN3
Quantity_NOC_CYAN4 = Quantity_NameOfColor.Quantity_NOC_CYAN4
Quantity_NOC_DARKGOLDENROD = Quantity_NameOfColor.Quantity_NOC_DARKGOLDENROD
Quantity_NOC_DARKGOLDENROD1 = Quantity_NameOfColor.Quantity_NOC_DARKGOLDENROD1
Quantity_NOC_DARKGOLDENROD2 = Quantity_NameOfColor.Quantity_NOC_DARKGOLDENROD2
Quantity_NOC_DARKGOLDENROD3 = Quantity_NameOfColor.Quantity_NOC_DARKGOLDENROD3
Quantity_NOC_DARKGOLDENROD4 = Quantity_NameOfColor.Quantity_NOC_DARKGOLDENROD4
Quantity_NOC_DARKGREEN = Quantity_NameOfColor.Quantity_NOC_DARKGREEN
Quantity_NOC_DARKKHAKI = Quantity_NameOfColor.Quantity_NOC_DARKKHAKI
Quantity_NOC_DARKOLIVEGREEN = Quantity_NameOfColor.Quantity_NOC_DARKOLIVEGREEN
Quantity_NOC_DARKOLIVEGREEN1 = Quantity_NameOfColor.Quantity_NOC_DARKOLIVEGREEN1
Quantity_NOC_DARKOLIVEGREEN2 = Quantity_NameOfColor.Quantity_NOC_DARKOLIVEGREEN2
Quantity_NOC_DARKOLIVEGREEN3 = Quantity_NameOfColor.Quantity_NOC_DARKOLIVEGREEN3
Quantity_NOC_DARKOLIVEGREEN4 = Quantity_NameOfColor.Quantity_NOC_DARKOLIVEGREEN4
Quantity_NOC_DARKORANGE = Quantity_NameOfColor.Quantity_NOC_DARKORANGE
Quantity_NOC_DARKORANGE1 = Quantity_NameOfColor.Quantity_NOC_DARKORANGE1
Quantity_NOC_DARKORANGE2 = Quantity_NameOfColor.Quantity_NOC_DARKORANGE2
Quantity_NOC_DARKORANGE3 = Quantity_NameOfColor.Quantity_NOC_DARKORANGE3
Quantity_NOC_DARKORANGE4 = Quantity_NameOfColor.Quantity_NOC_DARKORANGE4
Quantity_NOC_DARKORCHID = Quantity_NameOfColor.Quantity_NOC_DARKORCHID
Quantity_NOC_DARKORCHID1 = Quantity_NameOfColor.Quantity_NOC_DARKORCHID1
Quantity_NOC_DARKORCHID2 = Quantity_NameOfColor.Quantity_NOC_DARKORCHID2
Quantity_NOC_DARKORCHID3 = Quantity_NameOfColor.Quantity_NOC_DARKORCHID3
Quantity_NOC_DARKORCHID4 = Quantity_NameOfColor.Quantity_NOC_DARKORCHID4
Quantity_NOC_DARKSALMON = Quantity_NameOfColor.Quantity_NOC_DARKSALMON
Quantity_NOC_DARKSEAGREEN = Quantity_NameOfColor.Quantity_NOC_DARKSEAGREEN
Quantity_NOC_DARKSEAGREEN1 = Quantity_NameOfColor.Quantity_NOC_DARKSEAGREEN1
Quantity_NOC_DARKSEAGREEN2 = Quantity_NameOfColor.Quantity_NOC_DARKSEAGREEN2
Quantity_NOC_DARKSEAGREEN3 = Quantity_NameOfColor.Quantity_NOC_DARKSEAGREEN3
Quantity_NOC_DARKSEAGREEN4 = Quantity_NameOfColor.Quantity_NOC_DARKSEAGREEN4
Quantity_NOC_DARKSLATEBLUE = Quantity_NameOfColor.Quantity_NOC_DARKSLATEBLUE
Quantity_NOC_DARKSLATEGRAY1 = Quantity_NameOfColor.Quantity_NOC_DARKSLATEGRAY1
Quantity_NOC_DARKSLATEGRAY2 = Quantity_NameOfColor.Quantity_NOC_DARKSLATEGRAY2
Quantity_NOC_DARKSLATEGRAY3 = Quantity_NameOfColor.Quantity_NOC_DARKSLATEGRAY3
Quantity_NOC_DARKSLATEGRAY4 = Quantity_NameOfColor.Quantity_NOC_DARKSLATEGRAY4
Quantity_NOC_DARKSLATEGRAY = Quantity_NameOfColor.Quantity_NOC_DARKSLATEGRAY
Quantity_NOC_DARKTURQUOISE = Quantity_NameOfColor.Quantity_NOC_DARKTURQUOISE
Quantity_NOC_DARKVIOLET = Quantity_NameOfColor.Quantity_NOC_DARKVIOLET
Quantity_NOC_DEEPPINK = Quantity_NameOfColor.Quantity_NOC_DEEPPINK
Quantity_NOC_DEEPPINK2 = Quantity_NameOfColor.Quantity_NOC_DEEPPINK2
Quantity_NOC_DEEPPINK3 = Quantity_NameOfColor.Quantity_NOC_DEEPPINK3
Quantity_NOC_DEEPPINK4 = Quantity_NameOfColor.Quantity_NOC_DEEPPINK4
Quantity_NOC_DEEPSKYBLUE1 = Quantity_NameOfColor.Quantity_NOC_DEEPSKYBLUE1
Quantity_NOC_DEEPSKYBLUE2 = Quantity_NameOfColor.Quantity_NOC_DEEPSKYBLUE2
Quantity_NOC_DEEPSKYBLUE3 = Quantity_NameOfColor.Quantity_NOC_DEEPSKYBLUE3
Quantity_NOC_DEEPSKYBLUE4 = Quantity_NameOfColor.Quantity_NOC_DEEPSKYBLUE4
Quantity_NOC_DODGERBLUE1 = Quantity_NameOfColor.Quantity_NOC_DODGERBLUE1
Quantity_NOC_DODGERBLUE2 = Quantity_NameOfColor.Quantity_NOC_DODGERBLUE2
Quantity_NOC_DODGERBLUE3 = Quantity_NameOfColor.Quantity_NOC_DODGERBLUE3
Quantity_NOC_DODGERBLUE4 = Quantity_NameOfColor.Quantity_NOC_DODGERBLUE4
Quantity_NOC_FIREBRICK = Quantity_NameOfColor.Quantity_NOC_FIREBRICK
Quantity_NOC_FIREBRICK1 = Quantity_NameOfColor.Quantity_NOC_FIREBRICK1
Quantity_NOC_FIREBRICK2 = Quantity_NameOfColor.Quantity_NOC_FIREBRICK2
Quantity_NOC_FIREBRICK3 = Quantity_NameOfColor.Quantity_NOC_FIREBRICK3
Quantity_NOC_FIREBRICK4 = Quantity_NameOfColor.Quantity_NOC_FIREBRICK4
Quantity_NOC_FLORALWHITE = Quantity_NameOfColor.Quantity_NOC_FLORALWHITE
Quantity_NOC_FORESTGREEN = Quantity_NameOfColor.Quantity_NOC_FORESTGREEN
Quantity_NOC_GAINSBORO = Quantity_NameOfColor.Quantity_NOC_GAINSBORO
Quantity_NOC_GHOSTWHITE = Quantity_NameOfColor.Quantity_NOC_GHOSTWHITE
Quantity_NOC_GOLD = Quantity_NameOfColor.Quantity_NOC_GOLD
Quantity_NOC_GOLD1 = Quantity_NameOfColor.Quantity_NOC_GOLD1
Quantity_NOC_GOLD2 = Quantity_NameOfColor.Quantity_NOC_GOLD2
Quantity_NOC_GOLD3 = Quantity_NameOfColor.Quantity_NOC_GOLD3
Quantity_NOC_GOLD4 = Quantity_NameOfColor.Quantity_NOC_GOLD4
Quantity_NOC_GOLDENROD = Quantity_NameOfColor.Quantity_NOC_GOLDENROD
Quantity_NOC_GOLDENROD1 = Quantity_NameOfColor.Quantity_NOC_GOLDENROD1
Quantity_NOC_GOLDENROD2 = Quantity_NameOfColor.Quantity_NOC_GOLDENROD2
Quantity_NOC_GOLDENROD3 = Quantity_NameOfColor.Quantity_NOC_GOLDENROD3
Quantity_NOC_GOLDENROD4 = Quantity_NameOfColor.Quantity_NOC_GOLDENROD4
Quantity_NOC_GRAY = Quantity_NameOfColor.Quantity_NOC_GRAY
Quantity_NOC_GRAY0 = Quantity_NameOfColor.Quantity_NOC_GRAY0
Quantity_NOC_GRAY1 = Quantity_NameOfColor.Quantity_NOC_GRAY1
Quantity_NOC_GRAY2 = Quantity_NameOfColor.Quantity_NOC_GRAY2
Quantity_NOC_GRAY3 = Quantity_NameOfColor.Quantity_NOC_GRAY3
Quantity_NOC_GRAY4 = Quantity_NameOfColor.Quantity_NOC_GRAY4
Quantity_NOC_GRAY5 = Quantity_NameOfColor.Quantity_NOC_GRAY5
Quantity_NOC_GRAY6 = Quantity_NameOfColor.Quantity_NOC_GRAY6
Quantity_NOC_GRAY7 = Quantity_NameOfColor.Quantity_NOC_GRAY7
Quantity_NOC_GRAY8 = Quantity_NameOfColor.Quantity_NOC_GRAY8
Quantity_NOC_GRAY9 = Quantity_NameOfColor.Quantity_NOC_GRAY9
Quantity_NOC_GRAY10 = Quantity_NameOfColor.Quantity_NOC_GRAY10
Quantity_NOC_GRAY11 = Quantity_NameOfColor.Quantity_NOC_GRAY11
Quantity_NOC_GRAY12 = Quantity_NameOfColor.Quantity_NOC_GRAY12
Quantity_NOC_GRAY13 = Quantity_NameOfColor.Quantity_NOC_GRAY13
Quantity_NOC_GRAY14 = Quantity_NameOfColor.Quantity_NOC_GRAY14
Quantity_NOC_GRAY15 = Quantity_NameOfColor.Quantity_NOC_GRAY15
Quantity_NOC_GRAY16 = Quantity_NameOfColor.Quantity_NOC_GRAY16
Quantity_NOC_GRAY17 = Quantity_NameOfColor.Quantity_NOC_GRAY17
Quantity_NOC_GRAY18 = Quantity_NameOfColor.Quantity_NOC_GRAY18
Quantity_NOC_GRAY19 = Quantity_NameOfColor.Quantity_NOC_GRAY19
Quantity_NOC_GRAY20 = Quantity_NameOfColor.Quantity_NOC_GRAY20
Quantity_NOC_GRAY21 = Quantity_NameOfColor.Quantity_NOC_GRAY21
Quantity_NOC_GRAY22 = Quantity_NameOfColor.Quantity_NOC_GRAY22
Quantity_NOC_GRAY23 = Quantity_NameOfColor.Quantity_NOC_GRAY23
Quantity_NOC_GRAY24 = Quantity_NameOfColor.Quantity_NOC_GRAY24
Quantity_NOC_GRAY25 = Quantity_NameOfColor.Quantity_NOC_GRAY25
Quantity_NOC_GRAY26 = Quantity_NameOfColor.Quantity_NOC_GRAY26
Quantity_NOC_GRAY27 = Quantity_NameOfColor.Quantity_NOC_GRAY27
Quantity_NOC_GRAY28 = Quantity_NameOfColor.Quantity_NOC_GRAY28
Quantity_NOC_GRAY29 = Quantity_NameOfColor.Quantity_NOC_GRAY29
Quantity_NOC_GRAY30 = Quantity_NameOfColor.Quantity_NOC_GRAY30
Quantity_NOC_GRAY31 = Quantity_NameOfColor.Quantity_NOC_GRAY31
Quantity_NOC_GRAY32 = Quantity_NameOfColor.Quantity_NOC_GRAY32
Quantity_NOC_GRAY33 = Quantity_NameOfColor.Quantity_NOC_GRAY33
Quantity_NOC_GRAY34 = Quantity_NameOfColor.Quantity_NOC_GRAY34
Quantity_NOC_GRAY35 = Quantity_NameOfColor.Quantity_NOC_GRAY35
Quantity_NOC_GRAY36 = Quantity_NameOfColor.Quantity_NOC_GRAY36
Quantity_NOC_GRAY37 = Quantity_NameOfColor.Quantity_NOC_GRAY37
Quantity_NOC_GRAY38 = Quantity_NameOfColor.Quantity_NOC_GRAY38
Quantity_NOC_GRAY39 = Quantity_NameOfColor.Quantity_NOC_GRAY39
Quantity_NOC_GRAY40 = Quantity_NameOfColor.Quantity_NOC_GRAY40
Quantity_NOC_GRAY41 = Quantity_NameOfColor.Quantity_NOC_GRAY41
Quantity_NOC_GRAY42 = Quantity_NameOfColor.Quantity_NOC_GRAY42
Quantity_NOC_GRAY43 = Quantity_NameOfColor.Quantity_NOC_GRAY43
Quantity_NOC_GRAY44 = Quantity_NameOfColor.Quantity_NOC_GRAY44
Quantity_NOC_GRAY45 = Quantity_NameOfColor.Quantity_NOC_GRAY45
Quantity_NOC_GRAY46 = Quantity_NameOfColor.Quantity_NOC_GRAY46
Quantity_NOC_GRAY47 = Quantity_NameOfColor.Quantity_NOC_GRAY47
Quantity_NOC_GRAY48 = Quantity_NameOfColor.Quantity_NOC_GRAY48
Quantity_NOC_GRAY49 = Quantity_NameOfColor.Quantity_NOC_GRAY49
Quantity_NOC_GRAY50 = Quantity_NameOfColor.Quantity_NOC_GRAY50
Quantity_NOC_GRAY51 = Quantity_NameOfColor.Quantity_NOC_GRAY51
Quantity_NOC_GRAY52 = Quantity_NameOfColor.Quantity_NOC_GRAY52
Quantity_NOC_GRAY53 = Quantity_NameOfColor.Quantity_NOC_GRAY53
Quantity_NOC_GRAY54 = Quantity_NameOfColor.Quantity_NOC_GRAY54
Quantity_NOC_GRAY55 = Quantity_NameOfColor.Quantity_NOC_GRAY55
Quantity_NOC_GRAY56 = Quantity_NameOfColor.Quantity_NOC_GRAY56
Quantity_NOC_GRAY57 = Quantity_NameOfColor.Quantity_NOC_GRAY57
Quantity_NOC_GRAY58 = Quantity_NameOfColor.Quantity_NOC_GRAY58
Quantity_NOC_GRAY59 = Quantity_NameOfColor.Quantity_NOC_GRAY59
Quantity_NOC_GRAY60 = Quantity_NameOfColor.Quantity_NOC_GRAY60
Quantity_NOC_GRAY61 = Quantity_NameOfColor.Quantity_NOC_GRAY61
Quantity_NOC_GRAY62 = Quantity_NameOfColor.Quantity_NOC_GRAY62
Quantity_NOC_GRAY63 = Quantity_NameOfColor.Quantity_NOC_GRAY63
Quantity_NOC_GRAY64 = Quantity_NameOfColor.Quantity_NOC_GRAY64
Quantity_NOC_GRAY65 = Quantity_NameOfColor.Quantity_NOC_GRAY65
Quantity_NOC_GRAY66 = Quantity_NameOfColor.Quantity_NOC_GRAY66
Quantity_NOC_GRAY67 = Quantity_NameOfColor.Quantity_NOC_GRAY67
Quantity_NOC_GRAY68 = Quantity_NameOfColor.Quantity_NOC_GRAY68
Quantity_NOC_GRAY69 = Quantity_NameOfColor.Quantity_NOC_GRAY69
Quantity_NOC_GRAY70 = Quantity_NameOfColor.Quantity_NOC_GRAY70
Quantity_NOC_GRAY71 = Quantity_NameOfColor.Quantity_NOC_GRAY71
Quantity_NOC_GRAY72 = Quantity_NameOfColor.Quantity_NOC_GRAY72
Quantity_NOC_GRAY73 = Quantity_NameOfColor.Quantity_NOC_GRAY73
Quantity_NOC_GRAY74 = Quantity_NameOfColor.Quantity_NOC_GRAY74
Quantity_NOC_GRAY75 = Quantity_NameOfColor.Quantity_NOC_GRAY75
Quantity_NOC_GRAY76 = Quantity_NameOfColor.Quantity_NOC_GRAY76
Quantity_NOC_GRAY77 = Quantity_NameOfColor.Quantity_NOC_GRAY77
Quantity_NOC_GRAY78 = Quantity_NameOfColor.Quantity_NOC_GRAY78
Quantity_NOC_GRAY79 = Quantity_NameOfColor.Quantity_NOC_GRAY79
Quantity_NOC_GRAY80 = Quantity_NameOfColor.Quantity_NOC_GRAY80
Quantity_NOC_GRAY81 = Quantity_NameOfColor.Quantity_NOC_GRAY81
Quantity_NOC_GRAY82 = Quantity_NameOfColor.Quantity_NOC_GRAY82
Quantity_NOC_GRAY83 = Quantity_NameOfColor.Quantity_NOC_GRAY83
Quantity_NOC_GRAY85 = Quantity_NameOfColor.Quantity_NOC_GRAY85
Quantity_NOC_GRAY86 = Quantity_NameOfColor.Quantity_NOC_GRAY86
Quantity_NOC_GRAY87 = Quantity_NameOfColor.Quantity_NOC_GRAY87
Quantity_NOC_GRAY88 = Quantity_NameOfColor.Quantity_NOC_GRAY88
Quantity_NOC_GRAY89 = Quantity_NameOfColor.Quantity_NOC_GRAY89
Quantity_NOC_GRAY90 = Quantity_NameOfColor.Quantity_NOC_GRAY90
Quantity_NOC_GRAY91 = Quantity_NameOfColor.Quantity_NOC_GRAY91
Quantity_NOC_GRAY92 = Quantity_NameOfColor.Quantity_NOC_GRAY92
Quantity_NOC_GRAY93 = Quantity_NameOfColor.Quantity_NOC_GRAY93
Quantity_NOC_GRAY94 = Quantity_NameOfColor.Quantity_NOC_GRAY94
Quantity_NOC_GRAY95 = Quantity_NameOfColor.Quantity_NOC_GRAY95
Quantity_NOC_GRAY97 = Quantity_NameOfColor.Quantity_NOC_GRAY97
Quantity_NOC_GRAY98 = Quantity_NameOfColor.Quantity_NOC_GRAY98
Quantity_NOC_GRAY99 = Quantity_NameOfColor.Quantity_NOC_GRAY99
Quantity_NOC_GREEN = Quantity_NameOfColor.Quantity_NOC_GREEN
Quantity_NOC_GREEN1 = Quantity_NameOfColor.Quantity_NOC_GREEN1
Quantity_NOC_GREEN2 = Quantity_NameOfColor.Quantity_NOC_GREEN2
Quantity_NOC_GREEN3 = Quantity_NameOfColor.Quantity_NOC_GREEN3
Quantity_NOC_GREEN4 = Quantity_NameOfColor.Quantity_NOC_GREEN4
Quantity_NOC_GREENYELLOW = Quantity_NameOfColor.Quantity_NOC_GREENYELLOW
Quantity_NOC_HONEYDEW = Quantity_NameOfColor.Quantity_NOC_HONEYDEW
Quantity_NOC_HONEYDEW2 = Quantity_NameOfColor.Quantity_NOC_HONEYDEW2
Quantity_NOC_HONEYDEW3 = Quantity_NameOfColor.Quantity_NOC_HONEYDEW3
Quantity_NOC_HONEYDEW4 = Quantity_NameOfColor.Quantity_NOC_HONEYDEW4
Quantity_NOC_HOTPINK = Quantity_NameOfColor.Quantity_NOC_HOTPINK
Quantity_NOC_HOTPINK1 = Quantity_NameOfColor.Quantity_NOC_HOTPINK1
Quantity_NOC_HOTPINK2 = Quantity_NameOfColor.Quantity_NOC_HOTPINK2
Quantity_NOC_HOTPINK3 = Quantity_NameOfColor.Quantity_NOC_HOTPINK3
Quantity_NOC_HOTPINK4 = Quantity_NameOfColor.Quantity_NOC_HOTPINK4
Quantity_NOC_INDIANRED = Quantity_NameOfColor.Quantity_NOC_INDIANRED
Quantity_NOC_INDIANRED1 = Quantity_NameOfColor.Quantity_NOC_INDIANRED1
Quantity_NOC_INDIANRED2 = Quantity_NameOfColor.Quantity_NOC_INDIANRED2
Quantity_NOC_INDIANRED3 = Quantity_NameOfColor.Quantity_NOC_INDIANRED3
Quantity_NOC_INDIANRED4 = Quantity_NameOfColor.Quantity_NOC_INDIANRED4
Quantity_NOC_IVORY = Quantity_NameOfColor.Quantity_NOC_IVORY
Quantity_NOC_IVORY2 = Quantity_NameOfColor.Quantity_NOC_IVORY2
Quantity_NOC_IVORY3 = Quantity_NameOfColor.Quantity_NOC_IVORY3
Quantity_NOC_IVORY4 = Quantity_NameOfColor.Quantity_NOC_IVORY4
Quantity_NOC_KHAKI = Quantity_NameOfColor.Quantity_NOC_KHAKI
Quantity_NOC_KHAKI1 = Quantity_NameOfColor.Quantity_NOC_KHAKI1
Quantity_NOC_KHAKI2 = Quantity_NameOfColor.Quantity_NOC_KHAKI2
Quantity_NOC_KHAKI3 = Quantity_NameOfColor.Quantity_NOC_KHAKI3
Quantity_NOC_KHAKI4 = Quantity_NameOfColor.Quantity_NOC_KHAKI4
Quantity_NOC_LAVENDER = Quantity_NameOfColor.Quantity_NOC_LAVENDER
Quantity_NOC_LAVENDERBLUSH1 = Quantity_NameOfColor.Quantity_NOC_LAVENDERBLUSH1
Quantity_NOC_LAVENDERBLUSH2 = Quantity_NameOfColor.Quantity_NOC_LAVENDERBLUSH2
Quantity_NOC_LAVENDERBLUSH3 = Quantity_NameOfColor.Quantity_NOC_LAVENDERBLUSH3
Quantity_NOC_LAVENDERBLUSH4 = Quantity_NameOfColor.Quantity_NOC_LAVENDERBLUSH4
Quantity_NOC_LAWNGREEN = Quantity_NameOfColor.Quantity_NOC_LAWNGREEN
Quantity_NOC_LEMONCHIFFON1 = Quantity_NameOfColor.Quantity_NOC_LEMONCHIFFON1
Quantity_NOC_LEMONCHIFFON2 = Quantity_NameOfColor.Quantity_NOC_LEMONCHIFFON2
Quantity_NOC_LEMONCHIFFON3 = Quantity_NameOfColor.Quantity_NOC_LEMONCHIFFON3
Quantity_NOC_LEMONCHIFFON4 = Quantity_NameOfColor.Quantity_NOC_LEMONCHIFFON4
Quantity_NOC_LIGHTBLUE = Quantity_NameOfColor.Quantity_NOC_LIGHTBLUE
Quantity_NOC_LIGHTBLUE1 = Quantity_NameOfColor.Quantity_NOC_LIGHTBLUE1
Quantity_NOC_LIGHTBLUE2 = Quantity_NameOfColor.Quantity_NOC_LIGHTBLUE2
Quantity_NOC_LIGHTBLUE3 = Quantity_NameOfColor.Quantity_NOC_LIGHTBLUE3
Quantity_NOC_LIGHTBLUE4 = Quantity_NameOfColor.Quantity_NOC_LIGHTBLUE4
Quantity_NOC_LIGHTCORAL = Quantity_NameOfColor.Quantity_NOC_LIGHTCORAL
Quantity_NOC_LIGHTCYAN = Quantity_NameOfColor.Quantity_NOC_LIGHTCYAN
Quantity_NOC_LIGHTCYAN1 = Quantity_NameOfColor.Quantity_NOC_LIGHTCYAN1
Quantity_NOC_LIGHTCYAN2 = Quantity_NameOfColor.Quantity_NOC_LIGHTCYAN2
Quantity_NOC_LIGHTCYAN3 = Quantity_NameOfColor.Quantity_NOC_LIGHTCYAN3
Quantity_NOC_LIGHTCYAN4 = Quantity_NameOfColor.Quantity_NOC_LIGHTCYAN4
Quantity_NOC_LIGHTGOLDENROD = Quantity_NameOfColor.Quantity_NOC_LIGHTGOLDENROD
Quantity_NOC_LIGHTGOLDENROD1 = Quantity_NameOfColor.Quantity_NOC_LIGHTGOLDENROD1
Quantity_NOC_LIGHTGOLDENROD2 = Quantity_NameOfColor.Quantity_NOC_LIGHTGOLDENROD2
Quantity_NOC_LIGHTGOLDENROD3 = Quantity_NameOfColor.Quantity_NOC_LIGHTGOLDENROD3
Quantity_NOC_LIGHTGOLDENROD4 = Quantity_NameOfColor.Quantity_NOC_LIGHTGOLDENROD4
Quantity_NOC_LIGHTGOLDENRODYELLOW = Quantity_NameOfColor.Quantity_NOC_LIGHTGOLDENRODYELLOW
Quantity_NOC_LIGHTGRAY = Quantity_NameOfColor.Quantity_NOC_LIGHTGRAY
Quantity_NOC_LIGHTPINK = Quantity_NameOfColor.Quantity_NOC_LIGHTPINK
Quantity_NOC_LIGHTPINK1 = Quantity_NameOfColor.Quantity_NOC_LIGHTPINK1
Quantity_NOC_LIGHTPINK2 = Quantity_NameOfColor.Quantity_NOC_LIGHTPINK2
Quantity_NOC_LIGHTPINK3 = Quantity_NameOfColor.Quantity_NOC_LIGHTPINK3
Quantity_NOC_LIGHTPINK4 = Quantity_NameOfColor.Quantity_NOC_LIGHTPINK4
Quantity_NOC_LIGHTSALMON1 = Quantity_NameOfColor.Quantity_NOC_LIGHTSALMON1
Quantity_NOC_LIGHTSALMON2 = Quantity_NameOfColor.Quantity_NOC_LIGHTSALMON2
Quantity_NOC_LIGHTSALMON3 = Quantity_NameOfColor.Quantity_NOC_LIGHTSALMON3
Quantity_NOC_LIGHTSALMON4 = Quantity_NameOfColor.Quantity_NOC_LIGHTSALMON4
Quantity_NOC_LIGHTSEAGREEN = Quantity_NameOfColor.Quantity_NOC_LIGHTSEAGREEN
Quantity_NOC_LIGHTSKYBLUE = Quantity_NameOfColor.Quantity_NOC_LIGHTSKYBLUE
Quantity_NOC_LIGHTSKYBLUE1 = Quantity_NameOfColor.Quantity_NOC_LIGHTSKYBLUE1
Quantity_NOC_LIGHTSKYBLUE2 = Quantity_NameOfColor.Quantity_NOC_LIGHTSKYBLUE2
Quantity_NOC_LIGHTSKYBLUE3 = Quantity_NameOfColor.Quantity_NOC_LIGHTSKYBLUE3
Quantity_NOC_LIGHTSKYBLUE4 = Quantity_NameOfColor.Quantity_NOC_LIGHTSKYBLUE4
Quantity_NOC_LIGHTSLATEBLUE = Quantity_NameOfColor.Quantity_NOC_LIGHTSLATEBLUE
Quantity_NOC_LIGHTSLATEGRAY = Quantity_NameOfColor.Quantity_NOC_LIGHTSLATEGRAY
Quantity_NOC_LIGHTSTEELBLUE = Quantity_NameOfColor.Quantity_NOC_LIGHTSTEELBLUE
Quantity_NOC_LIGHTSTEELBLUE1 = Quantity_NameOfColor.Quantity_NOC_LIGHTSTEELBLUE1
Quantity_NOC_LIGHTSTEELBLUE2 = Quantity_NameOfColor.Quantity_NOC_LIGHTSTEELBLUE2
Quantity_NOC_LIGHTSTEELBLUE3 = Quantity_NameOfColor.Quantity_NOC_LIGHTSTEELBLUE3
Quantity_NOC_LIGHTSTEELBLUE4 = Quantity_NameOfColor.Quantity_NOC_LIGHTSTEELBLUE4
Quantity_NOC_LIGHTYELLOW = Quantity_NameOfColor.Quantity_NOC_LIGHTYELLOW
Quantity_NOC_LIGHTYELLOW2 = Quantity_NameOfColor.Quantity_NOC_LIGHTYELLOW2
Quantity_NOC_LIGHTYELLOW3 = Quantity_NameOfColor.Quantity_NOC_LIGHTYELLOW3
Quantity_NOC_LIGHTYELLOW4 = Quantity_NameOfColor.Quantity_NOC_LIGHTYELLOW4
Quantity_NOC_LIMEGREEN = Quantity_NameOfColor.Quantity_NOC_LIMEGREEN
Quantity_NOC_LINEN = Quantity_NameOfColor.Quantity_NOC_LINEN
Quantity_NOC_MAGENTA = Quantity_NameOfColor.Quantity_NOC_MAGENTA
Quantity_NOC_MAGENTA1 = Quantity_NameOfColor.Quantity_NOC_MAGENTA1
Quantity_NOC_MAGENTA2 = Quantity_NameOfColor.Quantity_NOC_MAGENTA2
Quantity_NOC_MAGENTA3 = Quantity_NameOfColor.Quantity_NOC_MAGENTA3
Quantity_NOC_MAGENTA4 = Quantity_NameOfColor.Quantity_NOC_MAGENTA4
Quantity_NOC_MAROON = Quantity_NameOfColor.Quantity_NOC_MAROON
Quantity_NOC_MAROON1 = Quantity_NameOfColor.Quantity_NOC_MAROON1
Quantity_NOC_MAROON2 = Quantity_NameOfColor.Quantity_NOC_MAROON2
Quantity_NOC_MAROON3 = Quantity_NameOfColor.Quantity_NOC_MAROON3
Quantity_NOC_MAROON4 = Quantity_NameOfColor.Quantity_NOC_MAROON4
Quantity_NOC_MEDIUMAQUAMARINE = Quantity_NameOfColor.Quantity_NOC_MEDIUMAQUAMARINE
Quantity_NOC_MEDIUMORCHID = Quantity_NameOfColor.Quantity_NOC_MEDIUMORCHID
Quantity_NOC_MEDIUMORCHID1 = Quantity_NameOfColor.Quantity_NOC_MEDIUMORCHID1
Quantity_NOC_MEDIUMORCHID2 = Quantity_NameOfColor.Quantity_NOC_MEDIUMORCHID2
Quantity_NOC_MEDIUMORCHID3 = Quantity_NameOfColor.Quantity_NOC_MEDIUMORCHID3
Quantity_NOC_MEDIUMORCHID4 = Quantity_NameOfColor.Quantity_NOC_MEDIUMORCHID4
Quantity_NOC_MEDIUMPURPLE = Quantity_NameOfColor.Quantity_NOC_MEDIUMPURPLE
Quantity_NOC_MEDIUMPURPLE1 = Quantity_NameOfColor.Quantity_NOC_MEDIUMPURPLE1
Quantity_NOC_MEDIUMPURPLE2 = Quantity_NameOfColor.Quantity_NOC_MEDIUMPURPLE2
Quantity_NOC_MEDIUMPURPLE3 = Quantity_NameOfColor.Quantity_NOC_MEDIUMPURPLE3
Quantity_NOC_MEDIUMPURPLE4 = Quantity_NameOfColor.Quantity_NOC_MEDIUMPURPLE4
Quantity_NOC_MEDIUMSEAGREEN = Quantity_NameOfColor.Quantity_NOC_MEDIUMSEAGREEN
Quantity_NOC_MEDIUMSLATEBLUE = Quantity_NameOfColor.Quantity_NOC_MEDIUMSLATEBLUE
Quantity_NOC_MEDIUMSPRINGGREEN = Quantity_NameOfColor.Quantity_NOC_MEDIUMSPRINGGREEN
Quantity_NOC_MEDIUMTURQUOISE = Quantity_NameOfColor.Quantity_NOC_MEDIUMTURQUOISE
Quantity_NOC_MEDIUMVIOLETRED = Quantity_NameOfColor.Quantity_NOC_MEDIUMVIOLETRED
Quantity_NOC_MIDNIGHTBLUE = Quantity_NameOfColor.Quantity_NOC_MIDNIGHTBLUE
Quantity_NOC_MINTCREAM = Quantity_NameOfColor.Quantity_NOC_MINTCREAM
Quantity_NOC_MISTYROSE = Quantity_NameOfColor.Quantity_NOC_MISTYROSE
Quantity_NOC_MISTYROSE2 = Quantity_NameOfColor.Quantity_NOC_MISTYROSE2
Quantity_NOC_MISTYROSE3 = Quantity_NameOfColor.Quantity_NOC_MISTYROSE3
Quantity_NOC_MISTYROSE4 = Quantity_NameOfColor.Quantity_NOC_MISTYROSE4
Quantity_NOC_MOCCASIN = Quantity_NameOfColor.Quantity_NOC_MOCCASIN
Quantity_NOC_NAVAJOWHITE1 = Quantity_NameOfColor.Quantity_NOC_NAVAJOWHITE1
Quantity_NOC_NAVAJOWHITE2 = Quantity_NameOfColor.Quantity_NOC_NAVAJOWHITE2
Quantity_NOC_NAVAJOWHITE3 = Quantity_NameOfColor.Quantity_NOC_NAVAJOWHITE3
Quantity_NOC_NAVAJOWHITE4 = Quantity_NameOfColor.Quantity_NOC_NAVAJOWHITE4
Quantity_NOC_NAVYBLUE = Quantity_NameOfColor.Quantity_NOC_NAVYBLUE
Quantity_NOC_OLDLACE = Quantity_NameOfColor.Quantity_NOC_OLDLACE
Quantity_NOC_OLIVEDRAB = Quantity_NameOfColor.Quantity_NOC_OLIVEDRAB
Quantity_NOC_OLIVEDRAB1 = Quantity_NameOfColor.Quantity_NOC_OLIVEDRAB1
Quantity_NOC_OLIVEDRAB2 = Quantity_NameOfColor.Quantity_NOC_OLIVEDRAB2
Quantity_NOC_OLIVEDRAB3 = Quantity_NameOfColor.Quantity_NOC_OLIVEDRAB3
Quantity_NOC_OLIVEDRAB4 = Quantity_NameOfColor.Quantity_NOC_OLIVEDRAB4
Quantity_NOC_ORANGE = Quantity_NameOfColor.Quantity_NOC_ORANGE
Quantity_NOC_ORANGE1 = Quantity_NameOfColor.Quantity_NOC_ORANGE1
Quantity_NOC_ORANGE2 = Quantity_NameOfColor.Quantity_NOC_ORANGE2
Quantity_NOC_ORANGE3 = Quantity_NameOfColor.Quantity_NOC_ORANGE3
Quantity_NOC_ORANGE4 = Quantity_NameOfColor.Quantity_NOC_ORANGE4
Quantity_NOC_ORANGERED = Quantity_NameOfColor.Quantity_NOC_ORANGERED
Quantity_NOC_ORANGERED1 = Quantity_NameOfColor.Quantity_NOC_ORANGERED1
Quantity_NOC_ORANGERED2 = Quantity_NameOfColor.Quantity_NOC_ORANGERED2
Quantity_NOC_ORANGERED3 = Quantity_NameOfColor.Quantity_NOC_ORANGERED3
Quantity_NOC_ORANGERED4 = Quantity_NameOfColor.Quantity_NOC_ORANGERED4
Quantity_NOC_ORCHID = Quantity_NameOfColor.Quantity_NOC_ORCHID
Quantity_NOC_ORCHID1 = Quantity_NameOfColor.Quantity_NOC_ORCHID1
Quantity_NOC_ORCHID2 = Quantity_NameOfColor.Quantity_NOC_ORCHID2
Quantity_NOC_ORCHID3 = Quantity_NameOfColor.Quantity_NOC_ORCHID3
Quantity_NOC_ORCHID4 = Quantity_NameOfColor.Quantity_NOC_ORCHID4
Quantity_NOC_PALEGOLDENROD = Quantity_NameOfColor.Quantity_NOC_PALEGOLDENROD
Quantity_NOC_PALEGREEN = Quantity_NameOfColor.Quantity_NOC_PALEGREEN
Quantity_NOC_PALEGREEN1 = Quantity_NameOfColor.Quantity_NOC_PALEGREEN1
Quantity_NOC_PALEGREEN2 = Quantity_NameOfColor.Quantity_NOC_PALEGREEN2
Quantity_NOC_PALEGREEN3 = Quantity_NameOfColor.Quantity_NOC_PALEGREEN3
Quantity_NOC_PALEGREEN4 = Quantity_NameOfColor.Quantity_NOC_PALEGREEN4
Quantity_NOC_PALETURQUOISE = Quantity_NameOfColor.Quantity_NOC_PALETURQUOISE
Quantity_NOC_PALETURQUOISE1 = Quantity_NameOfColor.Quantity_NOC_PALETURQUOISE1
Quantity_NOC_PALETURQUOISE2 = Quantity_NameOfColor.Quantity_NOC_PALETURQUOISE2
Quantity_NOC_PALETURQUOISE3 = Quantity_NameOfColor.Quantity_NOC_PALETURQUOISE3
Quantity_NOC_PALETURQUOISE4 = Quantity_NameOfColor.Quantity_NOC_PALETURQUOISE4
Quantity_NOC_PALEVIOLETRED = Quantity_NameOfColor.Quantity_NOC_PALEVIOLETRED
Quantity_NOC_PALEVIOLETRED1 = Quantity_NameOfColor.Quantity_NOC_PALEVIOLETRED1
Quantity_NOC_PALEVIOLETRED2 = Quantity_NameOfColor.Quantity_NOC_PALEVIOLETRED2
Quantity_NOC_PALEVIOLETRED3 = Quantity_NameOfColor.Quantity_NOC_PALEVIOLETRED3
Quantity_NOC_PALEVIOLETRED4 = Quantity_NameOfColor.Quantity_NOC_PALEVIOLETRED4
Quantity_NOC_PAPAYAWHIP = Quantity_NameOfColor.Quantity_NOC_PAPAYAWHIP
Quantity_NOC_PEACHPUFF = Quantity_NameOfColor.Quantity_NOC_PEACHPUFF
Quantity_NOC_PEACHPUFF2 = Quantity_NameOfColor.Quantity_NOC_PEACHPUFF2
Quantity_NOC_PEACHPUFF3 = Quantity_NameOfColor.Quantity_NOC_PEACHPUFF3
Quantity_NOC_PEACHPUFF4 = Quantity_NameOfColor.Quantity_NOC_PEACHPUFF4
Quantity_NOC_PERU = Quantity_NameOfColor.Quantity_NOC_PERU
Quantity_NOC_PINK = Quantity_NameOfColor.Quantity_NOC_PINK
Quantity_NOC_PINK1 = Quantity_NameOfColor.Quantity_NOC_PINK1
Quantity_NOC_PINK2 = Quantity_NameOfColor.Quantity_NOC_PINK2
Quantity_NOC_PINK3 = Quantity_NameOfColor.Quantity_NOC_PINK3
Quantity_NOC_PINK4 = Quantity_NameOfColor.Quantity_NOC_PINK4
Quantity_NOC_PLUM = Quantity_NameOfColor.Quantity_NOC_PLUM
Quantity_NOC_PLUM1 = Quantity_NameOfColor.Quantity_NOC_PLUM1
Quantity_NOC_PLUM2 = Quantity_NameOfColor.Quantity_NOC_PLUM2
Quantity_NOC_PLUM3 = Quantity_NameOfColor.Quantity_NOC_PLUM3
Quantity_NOC_PLUM4 = Quantity_NameOfColor.Quantity_NOC_PLUM4
Quantity_NOC_POWDERBLUE = Quantity_NameOfColor.Quantity_NOC_POWDERBLUE
Quantity_NOC_PURPLE = Quantity_NameOfColor.Quantity_NOC_PURPLE
Quantity_NOC_PURPLE1 = Quantity_NameOfColor.Quantity_NOC_PURPLE1
Quantity_NOC_PURPLE2 = Quantity_NameOfColor.Quantity_NOC_PURPLE2
Quantity_NOC_PURPLE3 = Quantity_NameOfColor.Quantity_NOC_PURPLE3
Quantity_NOC_PURPLE4 = Quantity_NameOfColor.Quantity_NOC_PURPLE4
Quantity_NOC_RED = Quantity_NameOfColor.Quantity_NOC_RED
Quantity_NOC_RED1 = Quantity_NameOfColor.Quantity_NOC_RED1
Quantity_NOC_RED2 = Quantity_NameOfColor.Quantity_NOC_RED2
Quantity_NOC_RED3 = Quantity_NameOfColor.Quantity_NOC_RED3
Quantity_NOC_RED4 = Quantity_NameOfColor.Quantity_NOC_RED4
Quantity_NOC_ROSYBROWN = Quantity_NameOfColor.Quantity_NOC_ROSYBROWN
Quantity_NOC_ROSYBROWN1 = Quantity_NameOfColor.Quantity_NOC_ROSYBROWN1
Quantity_NOC_ROSYBROWN2 = Quantity_NameOfColor.Quantity_NOC_ROSYBROWN2
Quantity_NOC_ROSYBROWN3 = Quantity_NameOfColor.Quantity_NOC_ROSYBROWN3
Quantity_NOC_ROSYBROWN4 = Quantity_NameOfColor.Quantity_NOC_ROSYBROWN4
Quantity_NOC_ROYALBLUE = Quantity_NameOfColor.Quantity_NOC_ROYALBLUE
Quantity_NOC_ROYALBLUE1 = Quantity_NameOfColor.Quantity_NOC_ROYALBLUE1
Quantity_NOC_ROYALBLUE2 = Quantity_NameOfColor.Quantity_NOC_ROYALBLUE2
Quantity_NOC_ROYALBLUE3 = Quantity_NameOfColor.Quantity_NOC_ROYALBLUE3
Quantity_NOC_ROYALBLUE4 = Quantity_NameOfColor.Quantity_NOC_ROYALBLUE4
Quantity_NOC_SADDLEBROWN = Quantity_NameOfColor.Quantity_NOC_SADDLEBROWN
Quantity_NOC_SALMON = Quantity_NameOfColor.Quantity_NOC_SALMON
Quantity_NOC_SALMON1 = Quantity_NameOfColor.Quantity_NOC_SALMON1
Quantity_NOC_SALMON2 = Quantity_NameOfColor.Quantity_NOC_SALMON2
Quantity_NOC_SALMON3 = Quantity_NameOfColor.Quantity_NOC_SALMON3
Quantity_NOC_SALMON4 = Quantity_NameOfColor.Quantity_NOC_SALMON4
Quantity_NOC_SANDYBROWN = Quantity_NameOfColor.Quantity_NOC_SANDYBROWN
Quantity_NOC_SEAGREEN = Quantity_NameOfColor.Quantity_NOC_SEAGREEN
Quantity_NOC_SEAGREEN1 = Quantity_NameOfColor.Quantity_NOC_SEAGREEN1
Quantity_NOC_SEAGREEN2 = Quantity_NameOfColor.Quantity_NOC_SEAGREEN2
Quantity_NOC_SEAGREEN3 = Quantity_NameOfColor.Quantity_NOC_SEAGREEN3
Quantity_NOC_SEAGREEN4 = Quantity_NameOfColor.Quantity_NOC_SEAGREEN4
Quantity_NOC_SEASHELL = Quantity_NameOfColor.Quantity_NOC_SEASHELL
Quantity_NOC_SEASHELL2 = Quantity_NameOfColor.Quantity_NOC_SEASHELL2
Quantity_NOC_SEASHELL3 = Quantity_NameOfColor.Quantity_NOC_SEASHELL3
Quantity_NOC_SEASHELL4 = Quantity_NameOfColor.Quantity_NOC_SEASHELL4
Quantity_NOC_BEET = Quantity_NameOfColor.Quantity_NOC_BEET
Quantity_NOC_TEAL = Quantity_NameOfColor.Quantity_NOC_TEAL
Quantity_NOC_SIENNA = Quantity_NameOfColor.Quantity_NOC_SIENNA
Quantity_NOC_SIENNA1 = Quantity_NameOfColor.Quantity_NOC_SIENNA1
Quantity_NOC_SIENNA2 = Quantity_NameOfColor.Quantity_NOC_SIENNA2
Quantity_NOC_SIENNA3 = Quantity_NameOfColor.Quantity_NOC_SIENNA3
Quantity_NOC_SIENNA4 = Quantity_NameOfColor.Quantity_NOC_SIENNA4
Quantity_NOC_SKYBLUE = Quantity_NameOfColor.Quantity_NOC_SKYBLUE
Quantity_NOC_SKYBLUE1 = Quantity_NameOfColor.Quantity_NOC_SKYBLUE1
Quantity_NOC_SKYBLUE2 = Quantity_NameOfColor.Quantity_NOC_SKYBLUE2
Quantity_NOC_SKYBLUE3 = Quantity_NameOfColor.Quantity_NOC_SKYBLUE3
Quantity_NOC_SKYBLUE4 = Quantity_NameOfColor.Quantity_NOC_SKYBLUE4
Quantity_NOC_SLATEBLUE = Quantity_NameOfColor.Quantity_NOC_SLATEBLUE
Quantity_NOC_SLATEBLUE1 = Quantity_NameOfColor.Quantity_NOC_SLATEBLUE1
Quantity_NOC_SLATEBLUE2 = Quantity_NameOfColor.Quantity_NOC_SLATEBLUE2
Quantity_NOC_SLATEBLUE3 = Quantity_NameOfColor.Quantity_NOC_SLATEBLUE3
Quantity_NOC_SLATEBLUE4 = Quantity_NameOfColor.Quantity_NOC_SLATEBLUE4
Quantity_NOC_SLATEGRAY1 = Quantity_NameOfColor.Quantity_NOC_SLATEGRAY1
Quantity_NOC_SLATEGRAY2 = Quantity_NameOfColor.Quantity_NOC_SLATEGRAY2
Quantity_NOC_SLATEGRAY3 = Quantity_NameOfColor.Quantity_NOC_SLATEGRAY3
Quantity_NOC_SLATEGRAY4 = Quantity_NameOfColor.Quantity_NOC_SLATEGRAY4
Quantity_NOC_SLATEGRAY = Quantity_NameOfColor.Quantity_NOC_SLATEGRAY
Quantity_NOC_SNOW = Quantity_NameOfColor.Quantity_NOC_SNOW
Quantity_NOC_SNOW2 = Quantity_NameOfColor.Quantity_NOC_SNOW2
Quantity_NOC_SNOW3 = Quantity_NameOfColor.Quantity_NOC_SNOW3
Quantity_NOC_SNOW4 = Quantity_NameOfColor.Quantity_NOC_SNOW4
Quantity_NOC_SPRINGGREEN = Quantity_NameOfColor.Quantity_NOC_SPRINGGREEN
Quantity_NOC_SPRINGGREEN2 = Quantity_NameOfColor.Quantity_NOC_SPRINGGREEN2
Quantity_NOC_SPRINGGREEN3 = Quantity_NameOfColor.Quantity_NOC_SPRINGGREEN3
Quantity_NOC_SPRINGGREEN4 = Quantity_NameOfColor.Quantity_NOC_SPRINGGREEN4
Quantity_NOC_STEELBLUE = Quantity_NameOfColor.Quantity_NOC_STEELBLUE
Quantity_NOC_STEELBLUE1 = Quantity_NameOfColor.Quantity_NOC_STEELBLUE1
Quantity_NOC_STEELBLUE2 = Quantity_NameOfColor.Quantity_NOC_STEELBLUE2
Quantity_NOC_STEELBLUE3 = Quantity_NameOfColor.Quantity_NOC_STEELBLUE3
Quantity_NOC_STEELBLUE4 = Quantity_NameOfColor.Quantity_NOC_STEELBLUE4
Quantity_NOC_TAN = Quantity_NameOfColor.Quantity_NOC_TAN
Quantity_NOC_TAN1 = Quantity_NameOfColor.Quantity_NOC_TAN1
Quantity_NOC_TAN2 = Quantity_NameOfColor.Quantity_NOC_TAN2
Quantity_NOC_TAN3 = Quantity_NameOfColor.Quantity_NOC_TAN3
Quantity_NOC_TAN4 = Quantity_NameOfColor.Quantity_NOC_TAN4
Quantity_NOC_THISTLE = Quantity_NameOfColor.Quantity_NOC_THISTLE
Quantity_NOC_THISTLE1 = Quantity_NameOfColor.Quantity_NOC_THISTLE1
Quantity_NOC_THISTLE2 = Quantity_NameOfColor.Quantity_NOC_THISTLE2
Quantity_NOC_THISTLE3 = Quantity_NameOfColor.Quantity_NOC_THISTLE3
Quantity_NOC_THISTLE4 = Quantity_NameOfColor.Quantity_NOC_THISTLE4
Quantity_NOC_TOMATO = Quantity_NameOfColor.Quantity_NOC_TOMATO
Quantity_NOC_TOMATO1 = Quantity_NameOfColor.Quantity_NOC_TOMATO1
Quantity_NOC_TOMATO2 = Quantity_NameOfColor.Quantity_NOC_TOMATO2
Quantity_NOC_TOMATO3 = Quantity_NameOfColor.Quantity_NOC_TOMATO3
Quantity_NOC_TOMATO4 = Quantity_NameOfColor.Quantity_NOC_TOMATO4
Quantity_NOC_TURQUOISE = Quantity_NameOfColor.Quantity_NOC_TURQUOISE
Quantity_NOC_TURQUOISE1 = Quantity_NameOfColor.Quantity_NOC_TURQUOISE1
Quantity_NOC_TURQUOISE2 = Quantity_NameOfColor.Quantity_NOC_TURQUOISE2
Quantity_NOC_TURQUOISE3 = Quantity_NameOfColor.Quantity_NOC_TURQUOISE3
Quantity_NOC_TURQUOISE4 = Quantity_NameOfColor.Quantity_NOC_TURQUOISE4
Quantity_NOC_VIOLET = Quantity_NameOfColor.Quantity_NOC_VIOLET
Quantity_NOC_VIOLETRED = Quantity_NameOfColor.Quantity_NOC_VIOLETRED
Quantity_NOC_VIOLETRED1 = Quantity_NameOfColor.Quantity_NOC_VIOLETRED1
Quantity_NOC_VIOLETRED2 = Quantity_NameOfColor.Quantity_NOC_VIOLETRED2
Quantity_NOC_VIOLETRED3 = Quantity_NameOfColor.Quantity_NOC_VIOLETRED3
Quantity_NOC_VIOLETRED4 = Quantity_NameOfColor.Quantity_NOC_VIOLETRED4
Quantity_NOC_WHEAT = Quantity_NameOfColor.Quantity_NOC_WHEAT
Quantity_NOC_WHEAT1 = Quantity_NameOfColor.Quantity_NOC_WHEAT1
Quantity_NOC_WHEAT2 = Quantity_NameOfColor.Quantity_NOC_WHEAT2
Quantity_NOC_WHEAT3 = Quantity_NameOfColor.Quantity_NOC_WHEAT3
Quantity_NOC_WHEAT4 = Quantity_NameOfColor.Quantity_NOC_WHEAT4
Quantity_NOC_WHITESMOKE = Quantity_NameOfColor.Quantity_NOC_WHITESMOKE
Quantity_NOC_YELLOW = Quantity_NameOfColor.Quantity_NOC_YELLOW
Quantity_NOC_YELLOW1 = Quantity_NameOfColor.Quantity_NOC_YELLOW1
Quantity_NOC_YELLOW2 = Quantity_NameOfColor.Quantity_NOC_YELLOW2
Quantity_NOC_YELLOW3 = Quantity_NameOfColor.Quantity_NOC_YELLOW3
Quantity_NOC_YELLOW4 = Quantity_NameOfColor.Quantity_NOC_YELLOW4
Quantity_NOC_YELLOWGREEN = Quantity_NameOfColor.Quantity_NOC_YELLOWGREEN
Quantity_NOC_WHITE = Quantity_NameOfColor.Quantity_NOC_WHITE

class Quantity_TypeOfColor(IntEnum):
	Quantity_TOC_RGB = 0
	Quantity_TOC_sRGB = 1
	Quantity_TOC_HLS = 2
	Quantity_TOC_CIELab = 3
	Quantity_TOC_CIELch = 4
Quantity_TOC_RGB = Quantity_TypeOfColor.Quantity_TOC_RGB
Quantity_TOC_sRGB = Quantity_TypeOfColor.Quantity_TOC_sRGB
Quantity_TOC_HLS = Quantity_TypeOfColor.Quantity_TOC_HLS
Quantity_TOC_CIELab = Quantity_TypeOfColor.Quantity_TOC_CIELab
Quantity_TOC_CIELch = Quantity_TypeOfColor.Quantity_TOC_CIELch


def Handle_Quantity_HArray1OfColor_Create():
    return _Quantity.Handle_Quantity_HArray1OfColor_Create()

def Handle_Quantity_HArray1OfColor_DownCast(t):
    return _Quantity.Handle_Quantity_HArray1OfColor_DownCast(t)

def Handle_Quantity_HArray1OfColor_IsNull(t):
    return _Quantity.Handle_Quantity_HArray1OfColor_IsNull(t)
class Quantity_Array1OfColor(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self, *args):
        return _Quantity.Quantity_Array1OfColor_begin(self, *args)

    def cbegin(self):
        return _Quantity.Quantity_Array1OfColor_cbegin(self)

    def end(self, *args):
        return _Quantity.Quantity_Array1OfColor_end(self, *args)

    def cend(self):
        return _Quantity.Quantity_Array1OfColor_cend(self)

    def __init__(self, *args):
        _Quantity.Quantity_Array1OfColor_swiginit(self, _Quantity.new_Quantity_Array1OfColor(*args))
    __swig_destroy__ = _Quantity.delete_Quantity_Array1OfColor

    def Init(self, theValue):
        return _Quantity.Quantity_Array1OfColor_Init(self, theValue)

    def Size(self):
        return _Quantity.Quantity_Array1OfColor_Size(self)

    def Length(self):
        return _Quantity.Quantity_Array1OfColor_Length(self)

    def IsEmpty(self):
        return _Quantity.Quantity_Array1OfColor_IsEmpty(self)

    def Lower(self):
        return _Quantity.Quantity_Array1OfColor_Lower(self)

    def Upper(self):
        return _Quantity.Quantity_Array1OfColor_Upper(self)

    def Assign(self, theOther):
        return _Quantity.Quantity_Array1OfColor_Assign(self, theOther)

    def Move(self, *args):
        return _Quantity.Quantity_Array1OfColor_Move(self, *args)

    def Set(self, *args):
        return _Quantity.Quantity_Array1OfColor_Set(self, *args)

    def First(self):
        return _Quantity.Quantity_Array1OfColor_First(self)

    def ChangeFirst(self):
        return _Quantity.Quantity_Array1OfColor_ChangeFirst(self)

    def Last(self):
        return _Quantity.Quantity_Array1OfColor_Last(self)

    def ChangeLast(self):
        return _Quantity.Quantity_Array1OfColor_ChangeLast(self)

    def Value(self, theIndex):
        return _Quantity.Quantity_Array1OfColor_Value(self, theIndex)

    def ChangeValue(self, theIndex):
        return _Quantity.Quantity_Array1OfColor_ChangeValue(self, theIndex)

    def __call__(self, *args):
        return _Quantity.Quantity_Array1OfColor___call__(self, *args)

    def SetValue(self, *args):
        return _Quantity.Quantity_Array1OfColor_SetValue(self, *args)

    def UpdateLowerBound(self, theLower):
        return _Quantity.Quantity_Array1OfColor_UpdateLowerBound(self, theLower)

    def UpdateUpperBound(self, theUpper):
        return _Quantity.Quantity_Array1OfColor_UpdateUpperBound(self, theUpper)

    def Resize(self, theLower, theUpper, theToCopyData):
        return _Quantity.Quantity_Array1OfColor_Resize(self, theLower, theUpper, theToCopyData)

    def IsDeletable(self):
        return _Quantity.Quantity_Array1OfColor_IsDeletable(self)

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register Quantity_Array1OfColor in _Quantity:
_Quantity.Quantity_Array1OfColor_swigregister(Quantity_Array1OfColor)
class Quantity_Color(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Return
        -------
        None

        Description
        -----------
        Creates Quantity_NOC_YELLOW color (for historical reasons).

        Parameters
        ----------
        theName: Quantity_NameOfColor

        Return
        -------
        None

        Description
        -----------
        Creates the color from enumeration value.

        Parameters
        ----------
        theC1: float
        theC2: float
        theC3: float
        theType: Quantity_TypeOfColor

        Return
        -------
        None

        Description
        -----------
        Creates a color according to the definition system theType. Throws exception if values are out of range.

        Parameters
        ----------
        theRgb: NCollection_Vec3<float>

        Return
        -------
        None

        Description
        -----------
        Define color from linear RGB values.

        """
        _Quantity.Quantity_Color_swiginit(self, _Quantity.new_Quantity_Color(*args))

    @staticmethod
    def Argb2color(*args):
        r"""

        Parameters
        ----------
        theARGB: int
        theColor: Quantity_Color

        Return
        -------
        None

        Description
        -----------
        Convert integer ARGB value to Color. Alpha bits are ignored. Note that this packing does NOT involve linear -> non-linear sRGB conversion, as would be usually expected to preserve higher (for human eye) color precision in 4 bytes.

        """
        return _Quantity.Quantity_Color_Argb2color(*args)

    def Blue(self, *args):
        r"""
        Return
        -------
        float

        Description
        -----------
        Returns the Blue component (quantity of blue) of the color within range [0.0; 1.0].

        """
        return _Quantity.Quantity_Color_Blue(self, *args)

    def ChangeContrast(self, *args):
        r"""

        Parameters
        ----------
        theDelta: float

        Return
        -------
        None

        Description
        -----------
        Increases or decreases the contrast (variation of the saturation). The delta is a percentage. Any value greater than zero will increase the contrast. The variation is expressed as a percentage of the current value.

        """
        return _Quantity.Quantity_Color_ChangeContrast(self, *args)

    def ChangeIntensity(self, *args):
        r"""

        Parameters
        ----------
        theDelta: float

        Return
        -------
        None

        Description
        -----------
        Increases or decreases the intensity (variation of the lightness). The delta is a percentage. Any value greater than zero will increase the intensity. The variation is expressed as a percentage of the current value.

        """
        return _Quantity.Quantity_Color_ChangeIntensity(self, *args)

    @staticmethod
    def Color2argb(*args):
        r"""

        Parameters
        ----------
        theColor: Quantity_Color

        Return
        -------
        theARGB: int

        Description
        -----------
        Convert the color value to ARGB integer value, with alpha equals to 0. So the output is formatted as 0x00RRGGBB. Note that this unpacking does NOT involve non-linear sRGB -> linear RGB conversion, as would be usually expected for RGB color packed into 4 bytes. 
        Input parameter: theColor color to convert @param[out] theARGB result color encoded as integer.

        """
        return _Quantity.Quantity_Color_Color2argb(*args)

    @staticmethod
    def ColorFromHex(*args):
        r"""

        Parameters
        ----------
        theHexColorString: str
        theColor: Quantity_Color

        Return
        -------
        bool

        Description
        -----------
        Parses the string as a hex color (like '#FF0' for short sRGB color, or '#FFFF00' for sRGB color) 
        Parameter theHexColorString the string to be parsed 
        Parameter theColor a color that is a result of parsing 
        Return: true if parsing was successful, or false otherwise.

        """
        return _Quantity.Quantity_Color_ColorFromHex(*args)

    @staticmethod
    def ColorFromName(*args):
        r"""

        Parameters
        ----------
        theName: str

        Return
        -------
        theColor: Quantity_NameOfColor

        Description
        -----------
        Finds color from predefined names. For example, the name of the color which corresponds to 'BLACK' is Quantity_NOC_BLACK. Returns False if name is unknown.

        Parameters
        ----------
        theColorNameString: str
        theColor: Quantity_Color

        Return
        -------
        bool

        Description
        -----------
        Finds color from predefined names. 
        Parameter theColorNameString the color name 
        Parameter theColor a found color 
        Return: false if the color name is unknown, or true if the search by color name was successful.

        """
        return _Quantity.Quantity_Color_ColorFromName(*args)

    @staticmethod
    def ColorToHex(*args):
        r"""

        Parameters
        ----------
        theColor: Quantity_Color
        theToPrefixHash: bool (optional, default to true)

        Return
        -------
        TCollection_AsciiString

        Description
        -----------
        Returns hex sRGB string in format '#FFAAFF'.

        """
        return _Quantity.Quantity_Color_ColorToHex(*args)

    @staticmethod
    def Convert_HLS_To_LinearRGB(*args):
        r"""

        Parameters
        ----------
        theHls: NCollection_Vec3<float>

        Return
        -------
        NCollection_Vec3<float >

        Description
        -----------
        Converts HLS components into linear RGB ones.

        """
        return _Quantity.Quantity_Color_Convert_HLS_To_LinearRGB(*args)

    @staticmethod
    def Convert_HLS_To_sRGB(*args):
        r"""

        Parameters
        ----------
        theHls: NCollection_Vec3<float>

        Return
        -------
        NCollection_Vec3<float >

        Description
        -----------
        Converts HLS components into RGB ones.

        """
        return _Quantity.Quantity_Color_Convert_HLS_To_sRGB(*args)

    @staticmethod
    def Convert_Lab_To_Lch(*args):
        r"""

        Parameters
        ----------
        theLab: NCollection_Vec3<float>

        Return
        -------
        NCollection_Vec3<float >

        Description
        -----------
        Converts CIE Lab components into CIE Lch ones.

        """
        return _Quantity.Quantity_Color_Convert_Lab_To_Lch(*args)

    @staticmethod
    def Convert_Lab_To_LinearRGB(*args):
        r"""

        Parameters
        ----------
        theLab: NCollection_Vec3<float>

        Return
        -------
        NCollection_Vec3<float >

        Description
        -----------
        Converts CIE Lab components into linear RGB ones. Note that the resulting values may be out of the valid range for RGB.

        """
        return _Quantity.Quantity_Color_Convert_Lab_To_LinearRGB(*args)

    @staticmethod
    def Convert_Lch_To_Lab(*args):
        r"""

        Parameters
        ----------
        theLch: NCollection_Vec3<float>

        Return
        -------
        NCollection_Vec3<float >

        Description
        -----------
        Converts CIE Lch components into CIE Lab ones.

        """
        return _Quantity.Quantity_Color_Convert_Lch_To_Lab(*args)

    @staticmethod
    def Convert_LinearRGB_To_HLS(*args):
        r"""

        Parameters
        ----------
        theRgb: NCollection_Vec3<float>

        Return
        -------
        NCollection_Vec3<float >

        Description
        -----------
        Converts Linear RGB components into HLS ones.

        """
        return _Quantity.Quantity_Color_Convert_LinearRGB_To_HLS(*args)

    @staticmethod
    def Convert_LinearRGB_To_Lab(*args):
        r"""

        Parameters
        ----------
        theRgb: NCollection_Vec3<float>

        Return
        -------
        NCollection_Vec3<float >

        Description
        -----------
        Converts linear RGB components into CIE Lab ones.

        """
        return _Quantity.Quantity_Color_Convert_LinearRGB_To_Lab(*args)

    @staticmethod
    def Convert_LinearRGB_To_sRGB(*args):
        r"""

        Parameters
        ----------
        theLinearValue: float

        Return
        -------
        float

        Description
        -----------
        Convert linear RGB component into sRGB using OpenGL specs formula (double precision), also known as gamma correction.

        Parameters
        ----------
        theLinearValue: float

        Return
        -------
        float

        Description
        -----------
        Convert linear RGB component into sRGB using OpenGL specs formula (single precision), also known as gamma correction.

        """
        return _Quantity.Quantity_Color_Convert_LinearRGB_To_sRGB(*args)

    @staticmethod
    def Convert_LinearRGB_To_sRGB_approx22(*args):
        r"""

        Parameters
        ----------
        theLinearValue: float

        Return
        -------
        float

        Description
        -----------
        Convert linear RGB component into sRGB using approximated uniform gamma coefficient 2.2.

        Parameters
        ----------
        theRGB: NCollection_Vec3<float>

        Return
        -------
        NCollection_Vec3<float >

        Description
        -----------
        Convert linear RGB components into sRGB using approximated uniform gamma coefficient 2.2.

        """
        return _Quantity.Quantity_Color_Convert_LinearRGB_To_sRGB_approx22(*args)

    @staticmethod
    def Convert_sRGB_To_HLS(*args):
        r"""

        Parameters
        ----------
        theRgb: NCollection_Vec3<float>

        Return
        -------
        NCollection_Vec3<float >

        Description
        -----------
        Converts sRGB components into HLS ones.

        """
        return _Quantity.Quantity_Color_Convert_sRGB_To_HLS(*args)

    @staticmethod
    def Convert_sRGB_To_LinearRGB(*args):
        r"""

        Parameters
        ----------
        thesRGBValue: float

        Return
        -------
        float

        Description
        -----------
        Convert sRGB component into linear RGB using OpenGL specs formula (double precision), also known as gamma correction.

        Parameters
        ----------
        thesRGBValue: float

        Return
        -------
        float

        Description
        -----------
        Convert sRGB component into linear RGB using OpenGL specs formula (single precision), also known as gamma correction.

        """
        return _Quantity.Quantity_Color_Convert_sRGB_To_LinearRGB(*args)

    @staticmethod
    def Convert_sRGB_To_LinearRGB_approx22(*args):
        r"""

        Parameters
        ----------
        thesRGBValue: float

        Return
        -------
        float

        Description
        -----------
        Convert sRGB component into linear RGB using approximated uniform gamma coefficient 2.2.

        Parameters
        ----------
        theRGB: NCollection_Vec3<float>

        Return
        -------
        NCollection_Vec3<float >

        Description
        -----------
        Convert sRGB components into linear RGB using approximated uniform gamma coefficient 2.2.

        """
        return _Quantity.Quantity_Color_Convert_sRGB_To_LinearRGB_approx22(*args)

    def Delta(self, *args):
        r"""

        Parameters
        ----------
        theColor: Quantity_Color

        Return
        -------
        DC: float
        DI: float

        Description
        -----------
        Returns the percentage change of contrast and intensity between this and another color. <DC> and <DI> are percentages, either positive or negative. The calculation is with respect to this color. If <DC> is positive then <self> is more contrasty. If <DI> is positive then <self> is more intense.

        """
        return _Quantity.Quantity_Color_Delta(self, *args)

    def DeltaE2000(self, *args):
        r"""

        Parameters
        ----------
        theOther: Quantity_Color

        Return
        -------
        float

        Description
        -----------
        Returns the value of the perceptual difference between this color and @p theOther, computed using the CIEDE2000 formula. The difference is in range [0, 100.], with 1 approximately corresponding to the minimal perceivable difference (usually difference 5 or greater is needed for the difference to be recognizable in practice).

        """
        return _Quantity.Quantity_Color_DeltaE2000(self, *args)

    def Distance(self, *args):
        r"""

        Parameters
        ----------
        theColor: Quantity_Color

        Return
        -------
        float

        Description
        -----------
        Returns the distance between two colors. It's a value between 0 and the square root of 3 (the black/white distance).

        """
        return _Quantity.Quantity_Color_Distance(self, *args)

    def DumpJson(self, depth=-1):
        r"""

        Parameters
        ----------
        depth: int, default=-1

        Return
        -------
        str

        Description
        -----------
        Dump the object to JSON string.

        Parameters
        ----------
        depth: int, default=-1

        Return
        -------
        str

        Description
        -----------
        Dump the object to JSON string.

        """
        return _Quantity.Quantity_Color_DumpJson(self, depth)

    @staticmethod
    def Epsilon(*args):
        r"""
        Return
        -------
        float

        Description
        -----------
        Returns the value used to compare two colors for equality; 0.0001 by default.

        """
        return _Quantity.Quantity_Color_Epsilon(*args)

    def Green(self, *args):
        r"""
        Return
        -------
        float

        Description
        -----------
        Returns the Green component (quantity of green) of the color within range [0.0; 1.0].

        """
        return _Quantity.Quantity_Color_Green(self, *args)

    @staticmethod
    def HlsRgb(*args):
        r"""

        Parameters
        ----------
        theH: float
        theL: float
        theS: float

        Return
        -------
        theR: float
        theG: float
        theB: float

        Description
        -----------
        Converts HLS components into sRGB ones.

        """
        return _Quantity.Quantity_Color_HlsRgb(*args)

    def Hue(self, *args):
        r"""
        Return
        -------
        float

        Description
        -----------
        Returns the Hue component (hue angle) of the color in degrees within range [0.0; 360.0], 0.0 being Red. -1.0 is a special value reserved for grayscale color (S should be 0.0).

        """
        return _Quantity.Quantity_Color_Hue(self, *args)

    def InitFromJson(self, json_string):
        r"""

        Parameters
        ----------
        json_string: the string

        Return
        -------
        bool

        Description
        -----------
        Init the object from a JSON string.

        """
        return _Quantity.Quantity_Color_InitFromJson(self, json_string)

    def IsDifferent(self, *args):
        r"""

        Parameters
        ----------
        theOther: Quantity_Color

        Return
        -------
        bool

        Description
        -----------
        Returns True if the distance between two colors is greater than Epsilon().

        """
        return _Quantity.Quantity_Color_IsDifferent(self, *args)

    def IsEqual(self, *args):
        r"""

        Parameters
        ----------
        theOther: Quantity_Color

        Return
        -------
        bool

        Description
        -----------
        Returns True if the distance between two colors is no greater than Epsilon().

        """
        return _Quantity.Quantity_Color_IsEqual(self, *args)

    def Light(self, *args):
        r"""
        Return
        -------
        float

        Description
        -----------
        Returns the Light component (value of the lightness) of the color within range [0.0; 1.0].

        """
        return _Quantity.Quantity_Color_Light(self, *args)

    @staticmethod
    def Name(*args):
        r"""
        Return
        -------
        Quantity_NameOfColor

        Description
        -----------
        Returns the name of the nearest color from the Quantity_NameOfColor enumeration.

        Parameters
        ----------
        theR: float
        theG: float
        theB: float

        Return
        -------
        Quantity_NameOfColor

        Description
        -----------
        Returns the color from Quantity_NameOfColor enumeration nearest to specified RGB values.

        """
        return _Quantity.Quantity_Color_Name(*args)

    def Red(self, *args):
        r"""
        Return
        -------
        float

        Description
        -----------
        Returns the Red component (quantity of red) of the color within range [0.0; 1.0].

        """
        return _Quantity.Quantity_Color_Red(self, *args)

    def Rgb(self, *args):
        r"""
        Return
        -------
        NCollection_Vec3<float>

        Description
        -----------
        Return the color as vector of 3 float elements.

        """
        return _Quantity.Quantity_Color_Rgb(self, *args)

    @staticmethod
    def RgbHls(*args):
        r"""

        Parameters
        ----------
        theR: float
        theG: float
        theB: float

        Return
        -------
        theH: float
        theL: float
        theS: float

        Description
        -----------
        Converts sRGB components into HLS ones.

        """
        return _Quantity.Quantity_Color_RgbHls(*args)

    def Saturation(self, *args):
        r"""
        Return
        -------
        float

        Description
        -----------
        Returns the Saturation component (value of the saturation) of the color within range [0.0; 1.0].

        """
        return _Quantity.Quantity_Color_Saturation(self, *args)

    @staticmethod
    def SetEpsilon(*args):
        r"""

        Parameters
        ----------
        theEpsilon: float

        Return
        -------
        None

        Description
        -----------
        Set the value used to compare two colors for equality.

        """
        return _Quantity.Quantity_Color_SetEpsilon(*args)

    def SetValues(self, *args):
        r"""

        Parameters
        ----------
        theName: Quantity_NameOfColor

        Return
        -------
        None

        Description
        -----------
        Updates the color from specified named color.

        Parameters
        ----------
        theC1: float
        theC2: float
        theC3: float
        theType: Quantity_TypeOfColor

        Return
        -------
        None

        Description
        -----------
        Updates a color according to the mode specified by theType. Throws exception if values are out of range.

        """
        return _Quantity.Quantity_Color_SetValues(self, *args)

    def SquareDistance(self, *args):
        r"""

        Parameters
        ----------
        theColor: Quantity_Color

        Return
        -------
        float

        Description
        -----------
        Returns the square of distance between two colors.

        """
        return _Quantity.Quantity_Color_SquareDistance(self, *args)

    @staticmethod
    def StringName(*args):
        r"""

        Parameters
        ----------
        theColor: Quantity_NameOfColor

        Return
        -------
        str

        Description
        -----------
        Returns the name of the color identified by the given Quantity_NameOfColor enumeration value.

        """
        return _Quantity.Quantity_Color_StringName(*args)

    def Values(self, *args):
        r"""

        Parameters
        ----------
        theType: Quantity_TypeOfColor

        Return
        -------
        theC1: float
        theC2: float
        theC3: float

        Description
        -----------
        Returns in theC1, theC2 and theC3 the components of this color according to the color system definition theType.

        """
        return _Quantity.Quantity_Color_Values(self, *args)

    def __ne_wrapper__(self, other):
        return _Quantity.Quantity_Color___ne_wrapper__(self, other)

    def __ne__(self, right):
        try:
            return self.__ne_wrapper__(right)
        except:
            return True


    def __eq_wrapper__(self, other):
        return _Quantity.Quantity_Color___eq_wrapper__(self, other)

    def __eq__(self, right):
        try:
            return self.__eq_wrapper__(right)
        except:
            return False


    def __getstate__(self):
        return self.DumpJson()


    def __setstate__(self, state):
        inst = Quantity_Color()
        if inst.InitFromJson(state):
            self.this = inst.this
        else:
            raise IOError('Failed to set state of Quantity_Color')


    __repr__ = _dumps_object

    __swig_destroy__ = _Quantity.delete_Quantity_Color

# Register Quantity_Color in _Quantity:
_Quantity.Quantity_Color_swigregister(Quantity_Color)
class Quantity_ColorRGBA(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Return
        -------
        None

        Description
        -----------
        Creates a color with the default value.

        Parameters
        ----------
        theRgb: Quantity_Color

        Return
        -------
        None

        Description
        -----------
        Creates the color with specified RGB value.

        Parameters
        ----------
        theRgb: Quantity_Color
        theAlpha: float

        Return
        -------
        None

        Description
        -----------
        Creates the color with specified RGBA values.

        Parameters
        ----------
        theRgba: NCollection_Vec4<float>

        Return
        -------
        None

        Description
        -----------
        Creates the color from RGBA vector.

        Parameters
        ----------
        theRed: float
        theGreen: float
        theBlue: float
        theAlpha: float

        Return
        -------
        None

        Description
        -----------
        Creates the color from RGBA values.

        """
        _Quantity.Quantity_ColorRGBA_swiginit(self, _Quantity.new_Quantity_ColorRGBA(*args))

    def Alpha(self, *args):
        r"""
        Return
        -------
        float

        Description
        -----------
        Return alpha value (1.0 means opaque, 0.0 means fully transparent).

        """
        return _Quantity.Quantity_ColorRGBA_Alpha(self, *args)

    def ChangeRGB(self, *args):
        r"""
        Return
        -------
        Quantity_Color

        Description
        -----------
        Modify RGB color components without affecting alpha value.

        """
        return _Quantity.Quantity_ColorRGBA_ChangeRGB(self, *args)

    @staticmethod
    def ColorFromHex(*args):
        r"""

        Parameters
        ----------
        theHexColorString: char *
        theColor: Quantity_ColorRGBA
        theAlphaComponentIsOff: bool (optional, default to false)

        Return
        -------
        bool

        Description
        -----------
        Parses the string as a hex color (like '#FF0' for short sRGB color, '#FF0F' for short sRGBA color, '#FFFF00' for RGB color, or '#FFFF00FF' for RGBA color) 
        Parameter theHexColorString the string to be parsed 
        Parameter theColor a color that is a result of parsing 
        Parameter theAlphaComponentIsOff the flag that indicates if a color alpha component is presented in the input string (false) or not (true) 
        Return: true if parsing was successful, or false otherwise.

        """
        return _Quantity.Quantity_ColorRGBA_ColorFromHex(*args)

    @staticmethod
    def ColorFromName(*args):
        r"""

        Parameters
        ----------
        theColorNameString: str
        theColor: Quantity_ColorRGBA

        Return
        -------
        bool

        Description
        -----------
        Finds color from predefined names. For example, the name of the color which corresponds to 'BLACK' is Quantity_NOC_BLACK. An alpha component is set to 1.0. 
        Parameter theColorNameString the color name 
        Parameter theColor a found color 
        Return: false if the color name is unknown, or true if the search by color name was successful.

        """
        return _Quantity.Quantity_ColorRGBA_ColorFromName(*args)

    @staticmethod
    def ColorToHex(*args):
        r"""

        Parameters
        ----------
        theColor: Quantity_ColorRGBA
        theToPrefixHash: bool (optional, default to true)

        Return
        -------
        TCollection_AsciiString

        Description
        -----------
        Returns hex sRGBA string in format '#RRGGBBAA'.

        """
        return _Quantity.Quantity_ColorRGBA_ColorToHex(*args)

    @staticmethod
    def Convert_LinearRGB_To_sRGB(*args):
        r"""

        Parameters
        ----------
        theRGB: NCollection_Vec4<float>

        Return
        -------
        NCollection_Vec4<float >

        Description
        -----------
        Convert linear RGB components into sRGB using OpenGL specs formula.

        """
        return _Quantity.Quantity_ColorRGBA_Convert_LinearRGB_To_sRGB(*args)

    @staticmethod
    def Convert_sRGB_To_LinearRGB(*args):
        r"""

        Parameters
        ----------
        theRGB: NCollection_Vec4<float>

        Return
        -------
        NCollection_Vec4<float >

        Description
        -----------
        Convert sRGB components into linear RGB using OpenGL specs formula.

        """
        return _Quantity.Quantity_ColorRGBA_Convert_sRGB_To_LinearRGB(*args)

    def DumpJson(self, depth=-1):
        r"""

        Parameters
        ----------
        depth: int, default=-1

        Return
        -------
        str

        Description
        -----------
        Dump the object to JSON string.

        Parameters
        ----------
        depth: int, default=-1

        Return
        -------
        str

        Description
        -----------
        Dump the object to JSON string.

        """
        return _Quantity.Quantity_ColorRGBA_DumpJson(self, depth)

    def GetRGB(self, *args):
        r"""
        Return
        -------
        Quantity_Color

        Description
        -----------
        Return RGB color value.

        """
        return _Quantity.Quantity_ColorRGBA_GetRGB(self, *args)

    def InitFromJson(self, json_string):
        r"""

        Parameters
        ----------
        json_string: the string

        Return
        -------
        bool

        Description
        -----------
        Init the object from a JSON string.

        """
        return _Quantity.Quantity_ColorRGBA_InitFromJson(self, json_string)

    def IsDifferent(self, *args):
        r"""

        Parameters
        ----------
        theOther: Quantity_ColorRGBA

        Return
        -------
        bool

        Description
        -----------
        Returns true if the distance between colors is greater than Epsilon().

        """
        return _Quantity.Quantity_ColorRGBA_IsDifferent(self, *args)

    def IsEqual(self, *args):
        r"""

        Parameters
        ----------
        theOther: Quantity_ColorRGBA

        Return
        -------
        bool

        Description
        -----------
        Two colors are considered to be equal if their distance is no greater than Epsilon().

        """
        return _Quantity.Quantity_ColorRGBA_IsEqual(self, *args)

    def SetAlpha(self, *args):
        r"""

        Parameters
        ----------
        theAlpha: float

        Return
        -------
        None

        Description
        -----------
        Assign the alpha value.

        """
        return _Quantity.Quantity_ColorRGBA_SetAlpha(self, *args)

    def SetRGB(self, *args):
        r"""

        Parameters
        ----------
        theRgb: Quantity_Color

        Return
        -------
        None

        Description
        -----------
        Assign RGB color components without affecting alpha value.

        """
        return _Quantity.Quantity_ColorRGBA_SetRGB(self, *args)

    def SetValues(self, *args):
        r"""

        Parameters
        ----------
        theRed: float
        theGreen: float
        theBlue: float
        theAlpha: float

        Return
        -------
        None

        Description
        -----------
        Assign new values to the color.

        """
        return _Quantity.Quantity_ColorRGBA_SetValues(self, *args)

    def __ne_wrapper__(self, other):
        return _Quantity.Quantity_ColorRGBA___ne_wrapper__(self, other)

    def __ne__(self, right):
        try:
            return self.__ne_wrapper__(right)
        except:
            return True


    def __eq_wrapper__(self, other):
        return _Quantity.Quantity_ColorRGBA___eq_wrapper__(self, other)

    def __eq__(self, right):
        try:
            return self.__eq_wrapper__(right)
        except:
            return False


    def __getstate__(self):
        return self.DumpJson()


    def __setstate__(self, state):
        inst = Quantity_ColorRGBA()
        if inst.InitFromJson(state):
            self.this = inst.this
        else:
            raise IOError('Failed to set state of Quantity_ColorRGBA')


    __repr__ = _dumps_object

    __swig_destroy__ = _Quantity.delete_Quantity_ColorRGBA

# Register Quantity_ColorRGBA in _Quantity:
_Quantity.Quantity_ColorRGBA_swigregister(Quantity_ColorRGBA)
class Quantity_Date(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Return
        -------
        None

        Description
        -----------
        Constructs a default date (00:00 GMT, January 1, 1979 (zero hour)); use the function SetValues to define the required date; or.

        Parameters
        ----------
        mm: int
        dd: int
        yyyy: int
        hh: int
        mn: int
        ss: int
        mis: int (optional, default to 0)
        mics: int (optional, default to 0)

        Return
        -------
        None

        Description
        -----------
        Constructs a date from the year yyyy, the month mm, the day dd, the hour hh, the minute mn, the second ss, the millisecond mis (defaulted to 0) and the microsecond mics (defaulted to 0).. With: 1 <= mm <= 12 1 <= dd <= max number of days of <mm> 1979 <= yyyy 0 <= hh <= 23 0 <= mn <= 59 0 <= ss <= 59 0 <= mis <= 999 0 <= mics <= 999 Exceptions Quantity_DateDefinitionError if mm, dd, hh, mn, ss, mis and mics are not the components of the valid date.

        """
        _Quantity.Quantity_Date_swiginit(self, _Quantity.new_Quantity_Date(*args))

    def Add(self, *args):
        r"""

        Parameters
        ----------
        aPeriod: Quantity_Period

        Return
        -------
        Quantity_Date

        Description
        -----------
        Adds a Period to a Date and returns the new Date.

        """
        return _Quantity.Quantity_Date_Add(self, *args)

    def Day(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        Returns Day of a Date.

        """
        return _Quantity.Quantity_Date_Day(self, *args)

    def Difference(self, *args):
        r"""

        Parameters
        ----------
        anOther: Quantity_Date

        Return
        -------
        Quantity_Period

        Description
        -----------
        Subtracts one Date from another one to find the period between and returns the value. The result is the absolute value between the difference of two dates.

        """
        return _Quantity.Quantity_Date_Difference(self, *args)

    def Hour(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        Returns Hour of a Date.

        """
        return _Quantity.Quantity_Date_Hour(self, *args)

    def IsEarlier(self, *args):
        r"""

        Parameters
        ----------
        anOther: Quantity_Date

        Return
        -------
        bool

        Description
        -----------
        Returns True if <self> is earlier than <other>.

        """
        return _Quantity.Quantity_Date_IsEarlier(self, *args)

    def IsEqual(self, *args):
        r"""

        Parameters
        ----------
        anOther: Quantity_Date

        Return
        -------
        bool

        Description
        -----------
        Returns True if both <self> and <other> are equal. This method is an alias of operator ==.

        """
        return _Quantity.Quantity_Date_IsEqual(self, *args)

    def IsLater(self, *args):
        r"""

        Parameters
        ----------
        anOther: Quantity_Date

        Return
        -------
        bool

        Description
        -----------
        Returns True if <self> is later then <other>.

        """
        return _Quantity.Quantity_Date_IsLater(self, *args)

    @staticmethod
    def IsLeap(*args):
        r"""

        Parameters
        ----------
        yy: int

        Return
        -------
        bool

        Description
        -----------
        Returns true if a year is a leap year. The leap years are divisible by 4 and not by 100 except the years divisible by 400.

        """
        return _Quantity.Quantity_Date_IsLeap(*args)

    @staticmethod
    def IsValid(*args):
        r"""

        Parameters
        ----------
        mm: int
        dd: int
        yy: int
        hh: int
        mn: int
        ss: int
        mis: int (optional, default to 0)
        mics: int (optional, default to 0)

        Return
        -------
        bool

        Description
        -----------
        Checks the validity of a date - returns true if a date defined from the year yyyy, the month mm, the day dd, the hour hh, the minute mn, the second ss, the millisecond mis (defaulted to 0) and the microsecond mics (defaulted to 0) is valid. A date must satisfy the conditions above: - yyyy is greater than or equal to 1979, - mm lies within the range [1, 12] (with 1 corresponding to January and 12 to December), - dd lies within a valid range for the month mm (from 1 to 28, 29, 30 or 31 depending on mm and whether yyyy is a leap year or not), - hh lies within the range [0, 23], - mn lies within the range [0, 59], - ss lies within the range [0, 59], - mis lies within the range [0, 999], - mics lies within the range [0, 999].C.

        """
        return _Quantity.Quantity_Date_IsValid(*args)

    def MicroSecond(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        Returns microsecond of a Date.

        """
        return _Quantity.Quantity_Date_MicroSecond(self, *args)

    def MilliSecond(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        Returns millisecond of a Date.

        """
        return _Quantity.Quantity_Date_MilliSecond(self, *args)

    def Minute(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        Returns minute of a Date.

        """
        return _Quantity.Quantity_Date_Minute(self, *args)

    def Month(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        Returns month of a Date.

        """
        return _Quantity.Quantity_Date_Month(self, *args)

    def Second(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        Returns seconde of a Date.

        """
        return _Quantity.Quantity_Date_Second(self, *args)

    def SetValues(self, *args):
        r"""

        Parameters
        ----------
        mm: int
        dd: int
        yy: int
        hh: int
        mn: int
        ss: int
        mis: int (optional, default to 0)
        mics: int (optional, default to 0)

        Return
        -------
        None

        Description
        -----------
        Assigns to this date the year yyyy, the month mm, the day dd, the hour hh, the minute mn, the second ss, the millisecond mis (defaulted to 0) and the microsecond mics (defaulted to 0). Exceptions Quantity_DateDefinitionError if mm, dd, hh, mn, ss, mis and mics are not components of a valid date.

        """
        return _Quantity.Quantity_Date_SetValues(self, *args)

    def Subtract(self, *args):
        r"""

        Parameters
        ----------
        aPeriod: Quantity_Period

        Return
        -------
        Quantity_Date

        Description
        -----------
        Subtracts a period from a Date and returns the new Date. Raises an exception if the result date is anterior to Jan 1, 1979.

        """
        return _Quantity.Quantity_Date_Subtract(self, *args)

    def Values(self, *args):
        r"""

        Parameters
        ----------

        Return
        -------
        mm: int
        dd: int
        yy: int
        hh: int
        mn: int
        ss: int
        mis: int
        mics: int

        Description
        -----------
        Gets a complete Date. - in mm - the month, - in dd - the day, - in yyyy - the year, - in hh - the hour, - in mn - the minute, - in ss - the second, - in mis - the millisecond, and - in mics - the microsecond.

        """
        return _Quantity.Quantity_Date_Values(self, *args)

    def Year(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        Returns year of a Date.

        """
        return _Quantity.Quantity_Date_Year(self, *args)

    def __add__(self, *args):
        r"""

        Parameters
        ----------
        aPeriod: Quantity_Period

        Return
        -------
        Quantity_Date

        Description
        -----------
        No available documentation.

        """
        return _Quantity.Quantity_Date___add__(self, *args)

    def __sub__(self, *args):
        r"""

        Parameters
        ----------
        aPeriod: Quantity_Period

        Return
        -------
        Quantity_Date

        Description
        -----------
        No available documentation.

        """
        return _Quantity.Quantity_Date___sub__(self, *args)

    def __eq_wrapper__(self, other):
        return _Quantity.Quantity_Date___eq_wrapper__(self, other)

    def __eq__(self, right):
        try:
            return self.__eq_wrapper__(right)
        except:
            return False


    def __getstate__(self):
        return self.DumpJson()


    def __setstate__(self, state):
        inst = Quantity_Date()
        if inst.InitFromJson(state):
            self.this = inst.this
        else:
            raise IOError('Failed to set state of Quantity_Date')


    __repr__ = _dumps_object

    __swig_destroy__ = _Quantity.delete_Quantity_Date

# Register Quantity_Date in _Quantity:
_Quantity.Quantity_Date_swigregister(Quantity_Date)
class Quantity_Period(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""

        Parameters
        ----------
        dd: int
        hh: int
        mn: int
        ss: int
        mis: int (optional, default to 0)
        mics: int (optional, default to 0)

        Return
        -------
        None

        Description
        -----------
        Creates a Period With: 0 <= dd 0 <= hh 0 <= mn 0 <= ss 0 <= mis 0 <= mics.

        Parameters
        ----------
        ss: int
        mics: int (optional, default to 0)

        Return
        -------
        None

        Description
        -----------
        Creates a Period with a number of seconds and microseconds. Exceptions Quantity_PeriodDefinitionError: - if the number of seconds expressed either by: - dd days, hh hours, mn minutes and ss seconds, or - Ss is less than 0. - if the number of microseconds expressed either by: - mis milliseconds and mics microseconds, or - Mics is less than 0.

        """
        _Quantity.Quantity_Period_swiginit(self, _Quantity.new_Quantity_Period(*args))

    def Add(self, *args):
        r"""

        Parameters
        ----------
        anOther: Quantity_Period

        Return
        -------
        Quantity_Period

        Description
        -----------
        Adds one Period to another one.

        """
        return _Quantity.Quantity_Period_Add(self, *args)

    def IsEqual(self, *args):
        r"""

        Parameters
        ----------
        anOther: Quantity_Period

        Return
        -------
        bool

        Description
        -----------
        Returns True if both <self> and <other> are equal.

        """
        return _Quantity.Quantity_Period_IsEqual(self, *args)

    def IsLonger(self, *args):
        r"""

        Parameters
        ----------
        anOther: Quantity_Period

        Return
        -------
        bool

        Description
        -----------
        Returns True if <self> is longer then <other>.

        """
        return _Quantity.Quantity_Period_IsLonger(self, *args)

    def IsShorter(self, *args):
        r"""

        Parameters
        ----------
        anOther: Quantity_Period

        Return
        -------
        bool

        Description
        -----------
        Returns True if <self> is shorter than <other>.

        """
        return _Quantity.Quantity_Period_IsShorter(self, *args)

    @staticmethod
    def IsValid(*args):
        r"""

        Parameters
        ----------
        dd: int
        hh: int
        mn: int
        ss: int
        mis: int (optional, default to 0)
        mics: int (optional, default to 0)

        Return
        -------
        bool

        Description
        -----------
        Checks the validity of a Period in form (dd,hh,mn,ss,mil,mic) With: 0 <= dd 0 <= hh 0 <= mn 0 <= ss 0 <= mis 0 <= mics.

        Parameters
        ----------
        ss: int
        mics: int (optional, default to 0)

        Return
        -------
        bool

        Description
        -----------
        Checks the validity of a Period in form (ss,mic) With: 0 <= ss 0 <= mics.

        """
        return _Quantity.Quantity_Period_IsValid(*args)

    def SetValues(self, *args):
        r"""

        Parameters
        ----------
        dd: int
        hh: int
        mn: int
        ss: int
        mis: int (optional, default to 0)
        mics: int (optional, default to 0)

        Return
        -------
        None

        Description
        -----------
        Assigns to this period the time interval defined - with dd days, hh hours, mn minutes, ss seconds, mis (defaulted to 0) milliseconds and mics (defaulted to 0) microseconds; or.

        Parameters
        ----------
        ss: int
        mics: int (optional, default to 0)

        Return
        -------
        None

        Description
        -----------
        Assigns to this period the time interval defined - with Ss seconds and Mics (defaulted to 0) microseconds. Exceptions Quantity_PeriodDefinitionError: - if the number of seconds expressed either by: - dd days, hh hours, mn minutes and ss seconds, or - Ss is less than 0. - if the number of microseconds expressed either by: - mis milliseconds and mics microseconds, or - Mics is less than 0.

        """
        return _Quantity.Quantity_Period_SetValues(self, *args)

    def Subtract(self, *args):
        r"""

        Parameters
        ----------
        anOther: Quantity_Period

        Return
        -------
        Quantity_Period

        Description
        -----------
        Subtracts one Period from another and returns the difference.

        """
        return _Quantity.Quantity_Period_Subtract(self, *args)

    def Values(self, *args):
        r"""

        Parameters
        ----------

        Return
        -------
        dd: int
        hh: int
        mn: int
        ss: int
        mis: int
        mics: int

        Description
        -----------
        Decomposes this period into a number of days,hours, minutes,seconds,milliseconds and microseconds Example of return values: 2 days, 15 hours, 0 minute , 0 second 0 millisecond and 0 microsecond.

        Parameters
        ----------

        Return
        -------
        ss: int
        mics: int

        Description
        -----------
        Returns the number of seconds in Ss and the number of remainding microseconds in Mics of this period. Example of return values: 3600 seconds and 0 microseconds.

        """
        return _Quantity.Quantity_Period_Values(self, *args)

    def __add__(self, *args):
        r"""

        Parameters
        ----------
        anOther: Quantity_Period

        Return
        -------
        Quantity_Period

        Description
        -----------
        No available documentation.

        """
        return _Quantity.Quantity_Period___add__(self, *args)

    def __sub__(self, *args):
        r"""

        Parameters
        ----------
        anOther: Quantity_Period

        Return
        -------
        Quantity_Period

        Description
        -----------
        No available documentation.

        """
        return _Quantity.Quantity_Period___sub__(self, *args)

    def __eq_wrapper__(self, other):
        return _Quantity.Quantity_Period___eq_wrapper__(self, other)

    def __eq__(self, right):
        try:
            return self.__eq_wrapper__(right)
        except:
            return False


    def __getstate__(self):
        return self.DumpJson()


    def __setstate__(self, state):
        inst = Quantity_Period()
        if inst.InitFromJson(state):
            self.this = inst.this
        else:
            raise IOError('Failed to set state of Quantity_Period')


    __repr__ = _dumps_object

    __swig_destroy__ = _Quantity.delete_Quantity_Period

# Register Quantity_Period in _Quantity:
_Quantity.Quantity_Period_swigregister(Quantity_Period)
class Quantity_HArray1OfColor(Quantity_Array1OfColor, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _Quantity.Quantity_HArray1OfColor_swiginit(self, _Quantity.new_Quantity_HArray1OfColor(*args))

    def Array1(self):
        return _Quantity.Quantity_HArray1OfColor_Array1(self)

    def ChangeArray1(self):
        return _Quantity.Quantity_HArray1OfColor_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_Quantity_HArray1OfColor_DownCast(t)

    __swig_destroy__ = _Quantity.delete_Quantity_HArray1OfColor

# Register Quantity_HArray1OfColor in _Quantity:
_Quantity.Quantity_HArray1OfColor_swigregister(Quantity_HArray1OfColor)



@deprecated
def Quantity_Color_Argb2color(*args):
	return Quantity_Color.Argb2color(*args)

@deprecated
def Quantity_Color_Color2argb(*args):
	return Quantity_Color.Color2argb(*args)

@deprecated
def Quantity_Color_ColorFromHex(*args):
	return Quantity_Color.ColorFromHex(*args)

@deprecated
def Quantity_Color_ColorFromName(*args):
	return Quantity_Color.ColorFromName(*args)

@deprecated
def Quantity_Color_ColorFromName(*args):
	return Quantity_Color.ColorFromName(*args)

@deprecated
def Quantity_Color_ColorToHex(*args):
	return Quantity_Color.ColorToHex(*args)

@deprecated
def Quantity_Color_Epsilon(*args):
	return Quantity_Color.Epsilon(*args)

@deprecated
def Quantity_Color_HlsRgb(*args):
	return Quantity_Color.HlsRgb(*args)

@deprecated
def Quantity_Color_Name(*args):
	return Quantity_Color.Name(*args)

@deprecated
def Quantity_Color_RgbHls(*args):
	return Quantity_Color.RgbHls(*args)

@deprecated
def Quantity_Color_SetEpsilon(*args):
	return Quantity_Color.SetEpsilon(*args)

@deprecated
def Quantity_Color_StringName(*args):
	return Quantity_Color.StringName(*args)

@deprecated
def Quantity_ColorRGBA_ColorFromHex(*args):
	return Quantity_ColorRGBA.ColorFromHex(*args)

@deprecated
def Quantity_ColorRGBA_ColorFromName(*args):
	return Quantity_ColorRGBA.ColorFromName(*args)

@deprecated
def Quantity_ColorRGBA_ColorToHex(*args):
	return Quantity_ColorRGBA.ColorToHex(*args)

@deprecated
def Quantity_Date_IsLeap(*args):
	return Quantity_Date.IsLeap(*args)

@deprecated
def Quantity_Date_IsValid(*args):
	return Quantity_Date.IsValid(*args)

@deprecated
def Quantity_Period_IsValid(*args):
	return Quantity_Period.IsValid(*args)

@deprecated
def Quantity_Period_IsValid(*args):
	return Quantity_Period.IsValid(*args)



